/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {

	const magazine_palace_pro_section_lists = ['post_grid_section','banner_post_section','sport_post_section','featured_Slider_section','three_col_slider_section','two_col_section','latest_post_section','main_slider_section','tag_section','breakingnews_section','slider_news_section','two_section_section','multi_post_section','post_carousel_section','have_missed_section','featured_post_section','main_slider_section','featured_category_section','blog_slider_section','instagram_section'];
    magazine_palace_pro_section_lists.forEach( magazine_palace_pro_homepage_scroll_preview );

    function magazine_palace_pro_homepage_scroll_preview(item, index) {
    	// Collect information from customize-controls.js about which panels are opening.
		wp.customize.bind( 'preview-ready', function() {
			
			// Initially hide the theme option placeholders on load.
			$( '.panel-placeholder' ).hide();

			wp.customize.preview.bind( item, function( data ) {
				// Only on the front page.
				if ( ! $( 'body' ).hasClass( 'home' ) ) {
					return;
				}

				// When the section is expanded, show and scroll to the content placeholders, exposing the edit links.
				if ( true === data.expanded ) {
					$('html, body').animate({
				        'scrollTop' : $('#magazine_palace_pro_'+item).position().top
				    });
				} 
			});

		});
 	}

	// Site title and description.
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.site-title a' ).text( to );
		} );
	} );
	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	} );

	// Header text color.
	wp.customize( 'header_textcolor', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a, .site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header title color.
	wp.customize( 'magazine_palace_pro_theme_options[header_title_color]', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title a' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header tagline color.
	wp.customize( 'magazine_palace_pro_theme_options[header_tagline_color]', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Color scheme.
	wp.customize( 'magazine_palace_pro_theme_options[colorscheme]', function( value ) {
		value.bind( function( to ) {

			// Update color body class.
			$( 'body' )
				.removeClass( 'colors-light colors-dark colors-custom' )
				.addClass( 'colors-' + to );
		});
	});

	// Custom color hue.
	wp.customize( 'magazine_palace_pro_theme_options[colorscheme_hue]', function( value ) {
		value.bind( function( to ) {

			// Update custom color CSS
			var style = $( '#custom-theme-colors' ),
			    color = style.data( 'color' ),
			    css = style.html();
			css = css.split( color ).join( to );
			style.html( css )
			     .data( 'color', to );
		} );
	} );

	// topbar
	wp.customize( 'magazine_palace_pro_theme_options[topbar_bg_color]', function( value ) {
		value.bind( function( to ) {
			$( '#top-navigation' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[topbar_text_color]', function( value ) {
		value.bind( function( to ) {
			$( '#top-navigation .main-navigation ul.nav-menu > li > a, #top-navigation time' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[topbar_btn_color]', function( value ) {
		value.bind( function( to ) {
			$( '#top-navigation .live-button .btn' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[topbar_btn_text_color]', function( value ) {
		value.bind( function( to ) {
			$( '#top-navigation .live-button .btn' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[topbar_btn_text]', function( value ) {
		value.bind( function( to ) {
			$( '#top-navigation .live-button .btn' ).text( to );
		} );
	} );

	// end topbar

	// header
	wp.customize( 'magazine_palace_pro_theme_options[header_nav_bg_color]', function( value ) {
		value.bind( function( to ) {
			$( '.header-one #site-navigation.main-navigation' ).css( 'background-color', to );
			$( '.header-two' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[header_icon_color]', function( value ) {
		value.bind( function( to ) {
			$( '.main-navigation ul.nav-menu > li.home-icon > a > svg' ).css( 'fill', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[header_text_color]', function( value ) {
		value.bind( function( to ) {
			$( '.main-navigation a, .main-navigation ul.nav-menu > li > a, .main-navigation form.search-form ::-webkit-input-placeholder' ).css( 'color', to );
			$( '.main-navigation form.search-form svg.icon-search, .main-navigation .nav-menu > li > a > svg.icon-down, .search-menu svg.icon-search' ).css( 'fill', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[header_search_bg]', function( value ) {
		value.bind( function( to ) {
			$( '.header-one .main-navigation form.search-form input' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[header_overlay_color]', function( value ) {
		value.bind( function( to ) {
			$( '.header-one .header-overlay' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[header_margin_button]', function( value ) {
		value.bind( function( to ) {
			$( '#masthead' ).css( 'margin-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[header_bg_image]', function( value ) {
		value.bind( function( to ) {		
			$( '.header-one .header-image' ).css( { 'background-image': 'url(' + to + ')', 'background-repeat': 'no-repeat', 'background-size': 'cover', 'background-position': 'center' } );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[header_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.header-one .header-image' ).css( 'padding-top', to + 'px' );
			$( '.header-one .header-image' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[header_search_enable]', function( value ) {
		value.bind( function( to ) {	
			if ( to == 'true' ) {
				$( '.header-one .main-navigation-search, .header-two .search-menu' ).css( 'display', 'block' );
				
			}else{
				$( '.header-one .main-navigation-search, .header-two .search-menu' ).css( 'display', 'none' );
				$( '.header-two .nav-menu' ).css( 'text-align', 'right' );
			}
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[header_home_icon_enable]', function( value ) {
		value.bind( function( to ) {	
			if ( to == 'true' ) {
				$( '.home-icon a' ).css( 'display', 'block' );
			}else{
				$( '.home-icon a' ).css( 'display', 'none' );
			}
		} );
	} );

	// end header

	// tag 

	wp.customize( 'magazine_palace_pro_theme_options[tag_label_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_tag_section h2' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[tag_label_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_tag_section h2' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[tag_row_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_tag_section .popular-tag-wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[tag_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_tag_section ul li a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[tag_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_tag_section h2' ).text( to );
		} );
	} );


	// end tag

	// breakingnews 

	wp.customize( 'magazine_palace_pro_theme_options[breakingnews_label_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_breakingnews_section .news-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[breakingnews_label_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_breakingnews_section .news-title' ).css( 'color', to );
			$( '#magazine_palace_pro_breakingnews_section .bubble svg' ).css( 'fill', to );
			$( '#magazine_palace_pro_breakingnews_section .bubble div' ).css( 'border', '3px solid ' + to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[breakingnews_row_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.breaking-news-post' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[breakingnews_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.breaking-news-post .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[breakingnews_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_breakingnews_section .news-title' ).text( to );
		} );
	} );


	// end breakingnews

	// two section
	wp.customize( 'magazine_palace_pro_theme_options[two_section_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_section_section .wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_section_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_section_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_section_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_section_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_section_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_section_section .wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_section_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_section_section .wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_section_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_section_section .wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_section_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_section_section .wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_section_title_one]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_section_section #magazine_palace_pro_slider_news_section .section-title' ).text( to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_section_title_two]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_section_section #magazine_pro_editors_choice_section .section-title' ).text( to );
		} );
	} );
	// end two section


	// multi post section
	wp.customize( 'magazine_palace_pro_theme_options[multi_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_multi_post_section .wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[multi_post_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_multi_post_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[multi_post_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_multi_post_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[multi_post_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_multi_post_section .magazine_palace_pro_two_col_section-wrapper .entry-container' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[multi_post_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_multi_post_section .magazine_palace_pro_two_col_section-wrapper .posted-on a, #magazine_palace_pro_multi_post_section .magazine_palace_pro_two_col_section-wrapper .min-read, #magazine_palace_pro_multi_post_section .magazine_palace_pro_two_col_section-wrapper .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[multi_post_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_multi_post_section .wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[multi_post_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_multi_post_section .wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[multi_post_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_multi_post_section .wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[multi_post_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_multi_post_section .wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[multi_post_col1_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_multi_post_section .first-col .section-title' ).text( to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[multi_post_col2_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_multi_post_section .second-col .section-title' ).text( to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[multi_post_col3_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_multi_post_section .third-col .section-title' ).text( to );
		} );
	} );
	// end multi post section

	// post carousel section
	wp.customize( 'magazine_palace_pro_theme_options[post_carousel_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_carousel_section .wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_carousel_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_carousel_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_carousel_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_carousel_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_carousel_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_carousel_section article .entry-container' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_carousel_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_carousel_section article .posted-on a, #magazine_palace_pro_post_carousel_section article .min-read, #magazine_palace_pro_post_carousel_section article .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_carousel_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_carousel_section .wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_carousel_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_carousel_section .wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_carousel_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_carousel_section .wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_carousel_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_carousel_section .wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_carousel_post_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_carousel_section article .entry-container' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_carousel_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_carousel_section .section-title' ).text( to );
		} );
	} );

	// end post carousel section

	// have missed section
	wp.customize( 'magazine_palace_pro_theme_options[have_missed_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_have_missed_section .wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[have_missed_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_have_missed_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[have_missed_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_have_missed_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[have_missed_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_have_missed_section article .entry-container' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[have_missed_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_have_missed_section article .posted-on a, #magazine_palace_pro_have_missed_section article .min-read, #magazine_palace_pro_have_missed_section article .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[have_missed_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_have_missed_section .wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[have_missed_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_have_missed_section .wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[have_missed_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_have_missed_section .wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[have_missed_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_have_missed_section .wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[have_missed_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_have_missed_section article .entry-container' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[have_missed_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_have_missed_section .section-title' ).text( to );
		} );
	} );

	// end have missed section

	// featured post section
	wp.customize( 'magazine_palace_pro_theme_options[featured_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_post_section .wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_post_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_post_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_post_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_post_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_post_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_post_section article .entry-container' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_post_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_post_section article .posted-on a, #magazine_palace_pro_featured_post_section article .min-read, #magazine_palace_pro_featured_post_section article .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_post_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_post_section .wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_post_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_post_section .wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_post_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_post_section .wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_post_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_post_section .wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_post_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_post_section article .entry-container' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_post_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_post_section .section-title' ).text( to );
		} );
	} );

	// end featured post section

	// main slider
	wp.customize( 'magazine_palace_pro_theme_options[main_slider_overlay_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_main_slider_section .overlay' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[main_slider_btn_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_main_slider_section .btn' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[main_slider_btn_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_main_slider_section .btn' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[main_slider_btn_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_main_slider_section .btn' ).text( to );
		} );
	} );
	// end main slider

	// featured category
	wp.customize( 'magazine_palace_pro_theme_options[featured_category_btn_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_category_section .entry-title a' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_category_btn_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_category_section .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_category_container_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_category_section .wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_category_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_category_section .wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_category_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_category_section .wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_category_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_category_section .wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_category_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_category_section .wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_category_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_category_section article .entry-container' ).css( 'padding', to + 'px' );
		} );
	} );
	// end featured category

	// blog slider section
	wp.customize( 'magazine_palace_pro_theme_options[blog_slider_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_blog_slider_section .wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[blog_slider_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_blog_slider_section article .entry-container' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[blog_slider_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_blog_slider_section article .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[blog_slider_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_blog_slider_section .wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[blog_slider_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_blog_slider_section .wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[blog_slider_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_blog_slider_section .wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[blog_slider_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_blog_slider_section .wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[blog_slider_post_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_blog_slider_section article .entry-container' ).css( 'padding', to + 'px' );
		} );
	} );

	// end blog slider section

	// post grid section
	wp.customize( 'magazine_palace_pro_theme_options[post_grid_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_grid_section' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_grid_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_grid_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_grid_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_grid_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_grid_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_grid_section article .entry-container' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_grid_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_grid_section article .posted-on a, #magazine_palace_pro_post_grid_section article .min-read, #magazine_palace_pro_post_grid_section article .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_grid_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_grid_section' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_grid_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_grid_section' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_grid_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_grid_section' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_grid_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_grid_section' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_grid_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_grid_section article .entry-container' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[post_grid_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_post_grid_section .section-title' ).text( to );
		} );
	} );

	// end post grid section

	// banner post section
	wp.customize( 'magazine_palace_pro_theme_options[banner_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_banner_post_section' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[banner_post_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_banner_post_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[banner_post_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_banner_post_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[banner_post_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_banner_post_section' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[banner_post_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_banner_post_section' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[banner_post_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_banner_post_section' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[banner_post_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_banner_post_section' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[banner_post_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_banner_post_section .section-title' ).text( to );
		} );
	} );

	// end banner post section

	// sport post section
	wp.customize( 'magazine_palace_pro_theme_options[sport_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_sport_post_section' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[sport_post_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_sport_post_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[sport_post_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_sport_post_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[sport_post_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_sport_post_section article .entry-container.color' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[sport_post_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_sport_post_section article .entry-container.color .posted-on a, #magazine_palace_pro_sport_post_section article .entry-container.color .min-read, #magazine_palace_pro_sport_post_section article .entry-container.color .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[sport_post_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_sport_post_section' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[sport_post_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_sport_post_section' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[sport_post_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_sport_post_section' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[sport_post_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_sport_post_section' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[sport_post_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_sport_post_section .section-title' ).text( to );
		} );
	} );

	// end sport post section

	// featured slider section
	wp.customize( 'magazine_palace_pro_theme_options[featured_slider_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_slider_section' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_slider_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_slider_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_slider_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_slider_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_slider_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_slider_section' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_slider_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_slider_section' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_slider_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_slider_section' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_slider_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_slider_section' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[featured_slider_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_featured_slider_section .section-title' ).text( to );
		} );
	} );

	// end featured slider section

	// three col section
	wp.customize( 'magazine_palace_pro_theme_options[three_col_slider_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_three_col_slider_section' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[three_col_slider_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_three_col_slider_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[three_col_slider_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_three_col_slider_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[three_col_slider_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_three_col_slider_section article .entry-container' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[three_col_slider_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_three_col_slider_section article .posted-on a, #magazine_palace_pro_three_col_slider_section article .min-read, #magazine_palace_pro_three_col_slider_section article .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[three_col_slider_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_three_col_slider_section' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[three_col_slider_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_three_col_slider_section' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[three_col_slider_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_three_col_slider_section' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[three_col_slider_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_three_col_slider_section' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[three_col_slider_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_three_col_slider_section article .entry-container' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[three_col_slider_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_three_col_slider_section .section-title' ).text( to );
		} );
	} );

	// end three col section

	// two col section
	wp.customize( 'magazine_palace_pro_theme_options[two_col_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_col_section' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_col_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_col_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_col_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_col_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_col_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_col_section article .entry-container' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_col_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_col_section article .posted-on a, #magazine_palace_pro_two_col_section article .min-read, #magazine_palace_pro_two_col_section article .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_col_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_col_section' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_col_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_col_section' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_col_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_col_section' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_col_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_col_section' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_col_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_col_section article .entry-container' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[two_col_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_two_col_section .section-title' ).text( to );
		} );
	} );

	// end two col section

	// latest post section
	wp.customize( 'magazine_palace_pro_theme_options[latest_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_latest_post_section' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[latest_post_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_latest_post_section .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[latest_post_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_latest_post_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[latest_post_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_latest_post_section article .entry-container' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[latest_post_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_latest_post_section article .posted-on a, #magazine_palace_pro_latest_post_section article .min-read, #magazine_palace_pro_latest_post_section article .entry-title a, #magazine_palace_pro_latest_post_section article .entry-content p' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[latest_post_btn_border_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_latest_post_section article .btn' ).css( 'border', '1px solid ' + to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[latest_post_btn_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_latest_post_section article .btn' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[latest_post_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_latest_post_section' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[latest_post_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_latest_post_section' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[latest_post_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_latest_post_section' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[latest_post_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_latest_post_section' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[latest_post_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_latest_post_section article .entry-container' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[latest_post_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#magazine_palace_pro_latest_post_section .section-title' ).text( to );
		} );
	} );

	// end latest post section

	// single post/page 
	wp.customize( 'magazine_palace_pro_theme_options[single_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper, .page #inner-content-wrapper' ).css( 'background-color', to );
		} );
	} );
	wp.customize( 'magazine_palace_pro_theme_options[single_post_related_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper #related-post' ).css( 'background-color', to );
		} );
	} );
	wp.customize( 'magazine_palace_pro_theme_options[single_post_entry_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper .entry-container' ).css( 'background-color', to );
		} );
	} );
	wp.customize( 'magazine_palace_pro_theme_options[single_post_comment_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper #comments' ).css( 'background-color', to );
		} );
	} );
	wp.customize( 'magazine_palace_pro_theme_options[single_post_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper, .page #inner-content-wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[single_post_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper, .page #inner-content-wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[single_post_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper, .page #inner-content-wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[single_post_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper, .page #inner-content-wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[single_post_related_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper #related-post' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[single_post_comment_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper #comments' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[single_post_entry_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper .entry-container.post-content' ).css( 'padding', to + 'px' );
		} );
	} );
	// end single post/page

	// widget 
	wp.customize( 'magazine_palace_pro_theme_options[widget_panel_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages, #right-sidebar' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[widget_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages .widget, #right-sidebar .widget' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[widget_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages,  #right-sidebar' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[widget_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages,  #right-sidebar' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[widget_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages,  #right-sidebar' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[widget_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages,  #right-sidebar' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[widget_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages .widget,  #right-sidebar .widget' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[widget_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages .wp-block-latest-comments__comment-meta,#secondary.inner-pages .entry-meta > span, #secondary.inner-pages p .about-us-post .entry-title, #secondary.inner-pages p, #secondary.inner-pages a, #secondary.inner-pages .widget h2, #secondary.inner-pages .widget ul li a, #secondary.inner-pages .widget .wp-block-search__label, #right-sidebar .widget ul li a, #right-sidebar .widget .wp-block-search__label, #right-sidebar .widget h2, #right-sidebar a, #right-sidebar p, #right-sidebar p .about-us-post .entry-title, #right-sidebar.inner-pages .wp-block-latest-comments__comment-meta, #right-sidebar.inner-pages .entry-meta > span' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[widget_post_content_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages .widget ul li .entry-container,  #right-sidebar .widget ul li .entry-container' ).css( 'background-color', to );
		} );
	} );

	

	// end widget

	// homepage
	wp.customize( 'magazine_palace_pro_theme_options[homepage_section_gap]', function( value ) {
		value.bind( function( to ) {		
			$( '.home-section' ).css( 'margin', to + 'px' );
			$( '#main-post-wrapper main div:first-child, #main-post-wrapper main div:last-child' ).css( 'margin-top', '0px' );
			$( '.right-sidebar #primary, .left-sidebar #primary' ).css( 'paddingright', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[homepage_main_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #main-post-wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[homepage_main_container_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #main-post-wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[homepage_main_container_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #main-post-wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[homepage_main_container_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #main-post-wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[homepage_main_container_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #main-post-wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );



	//end homepage

	// slider news 
	wp.customize( 'magazine_palace_pro_theme_options[slider_news_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[slider_news_slider_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper #magazine_palace_pro_slider_news_section' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[slider_news_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[slider_news_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[slider_news_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[slider_news_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[slider_news_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[slider_news_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );
	wp.customize( 'magazine_palace_pro_theme_options[slider_news_slider_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper #magazine_palace_pro_slider_news_section' ).css( 'padding', to + 'px' );
		} );
	} );
	// end slider news 

	// Archive Page 

	wp.customize( 'magazine_palace_pro_theme_options[archive_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#inner-content-wrapper.archive' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[archive_post_cotainer_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#inner-content-wrapper.archive .entry-container' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[archive_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#inner-content-wrapper.archive' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[archive_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#inner-content-wrapper.archive' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[archive_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#inner-content-wrapper.archive' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[archive_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#inner-content-wrapper.archive' ).css( 'padding-right', to + 'px' );
		} );
	} );

	// End Archive 

	// Layout 

	wp.customize( 'magazine_palace_pro_theme_options[wrapper_width]', function( value ) {
		value.bind( function( to ) {		
			$( '.wrapper' ).css( 'width', to + '%' );
			$( '#masthead.wrapper' ).css( 'width', to + '%' );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[wrapper_max_width]', function( value ) {
		value.bind( function( to ) {		
			$( '.wrapper' ).css( 'max-width', to + 'px' );
		} );
	} );

	// End Layout 

	// Footer 

	wp.customize( 'magazine_palace_pro_theme_options[footer_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#colophon' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[footer_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#colophon ul li a, #colophon .textwidget p, .site-info span, #colophon .site-info a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[footer_separator_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.footer-widgets-area .wrapper' ).css( 'border-bottom', '1px solid ' + to );
		} );
	} );

	wp.customize( 'magazine_palace_pro_theme_options[footer_top_margin]', function( value ) {
		value.bind( function( to ) {		
			$( '#colophon' ).css( 'margin-top', to + 'px' );
		} );
	} );
	// end footer


} )( jQuery );
