<?php
/**
 * Theme Palace functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Theme Palace
 * @subpackage Magazine Palace Pro
 * @since Magazine Palace Pro 1.0.0
 */

if ( ! function_exists( 'magazine_palace_pro_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function magazine_palace_pro_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Theme Palace, use a find and replace
		 * to change 'magazine-palace-pro' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'magazine-palace-pro' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		add_theme_support( 'register_block_pattern' ); 

		add_theme_support( 'register_block_style' ); 

		add_theme_support( 'responsive-embeds' );

		// Enable support for footer widgets.
		add_theme_support( 'footer-widgets', 4 );

		// Load Footer Widget Support.
		require_if_theme_supports( 'footer-widgets', get_template_directory() . '/inc/footer-widgets.php' );
		
		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 600, 450, true );

		// Set the default content width.
		$GLOBALS['content_width'] = 525;
		
		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'social' 	=> esc_html__( 'Social', 'magazine-palace-pro' ),
			'primary' 	=> esc_html__( 'Primary', 'magazine-palace-pro' ),
			'secondary' => esc_html__( 'Secondary', 'magazine-palace-pro' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'magazine_palace_pro_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// This setup supports logo, site-title & site-description
		add_theme_support( 'custom-logo', array(
			'height'      => 70,
			'width'       => 120,
			'flex-height' => true,
			'flex-width'  => true,
			'header-text' => array( 'site-title', 'site-description' ),
		) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/*
		 * This theme styles the visual editor to resemble the theme style,
		 * specifically font, colors, icons, and column width.
		 */
		add_editor_style( array( '/assets/css/editor-style' . magazine_palace_pro_min() . '.css', magazine_palace_pro_fonts_url() ) );

		// Gutenberg support
		add_theme_support( 'editor-color-palette', array(
	       	array(
				'name' => esc_html__( 'Blue', 'magazine-palace-pro' ),
				'slug' => 'blue',
				'color' => '#2c7dfa',
	       	),
	       	array(
	           	'name' => esc_html__( 'Green', 'magazine-palace-pro' ),
	           	'slug' => 'green',
	           	'color' => '#07d79c',
	       	),
	       	array(
	           	'name' => esc_html__( 'Orange', 'magazine-palace-pro' ),
	           	'slug' => 'orange',
	           	'color' => '#ff8737',
	       	),
	       	array(
	           	'name' => esc_html__( 'Black', 'magazine-palace-pro' ),
	           	'slug' => 'black',
	           	'color' => '#2f3633',
	       	),
	       	array(
	           	'name' => esc_html__( 'Grey', 'magazine-palace-pro' ),
	           	'slug' => 'grey',
	           	'color' => '#82868b',
	       	),
	   	));

		add_theme_support( 'align-wide' );
		add_theme_support( 'editor-font-sizes', array(
		   	array(
		       	'name' => esc_html__( 'small', 'magazine-palace-pro' ),
		       	'shortName' => esc_html__( 'S', 'magazine-palace-pro' ),
		       	'size' => 12,
		       	'slug' => 'small'
		   	),
		   	array(
		       	'name' => esc_html__( 'regular', 'magazine-palace-pro' ),
		       	'shortName' => esc_html__( 'M', 'magazine-palace-pro' ),
		       	'size' => 16,
		       	'slug' => 'regular'
		   	),
		   	array(
		       	'name' => esc_html__( 'larger', 'magazine-palace-pro' ),
		       	'shortName' => esc_html__( 'L', 'magazine-palace-pro' ),
		       	'size' => 36,
		       	'slug' => 'larger'
		   	),
		   	array(
		       	'name' => esc_html__( 'huge', 'magazine-palace-pro' ),
		       	'shortName' => esc_html__( 'XL', 'magazine-palace-pro' ),
		       	'size' => 48,
		       	'slug' => 'huge'
		   	)
		));
		add_theme_support('editor-styles');
		add_theme_support( 'wp-block-styles' );
	}
endif;
add_action( 'after_setup_theme', 'magazine_palace_pro_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function magazine_palace_pro_content_width() {

	$content_width = $GLOBALS['content_width'];


	$sidebar_position = magazine_palace_pro_layout();
	switch ( $sidebar_position ) {

	  case 'no-sidebar':
	    $content_width = 1170;
	    break;

	  case 'left-sidebar':
	  case 'right-sidebar':
	    $content_width = 819;
	    break;

	  default:
	    break;
	}

	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$content_width = 1170;
	}

	/**
	 * Filter Magazine Palace Pro content width of the theme.
	 *
	 * @since Magazine Palace Pro 1.0.0
	 *
	 * @param int $content_width Content width in pixels.
	 */
	$GLOBALS['content_width'] = apply_filters( 'magazine_palace_pro_content_width', $content_width );
}
add_action( 'template_redirect', 'magazine_palace_pro_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function magazine_palace_pro_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'magazine-palace-pro' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'magazine-palace-pro' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget-header"><h2 class="widget-title">',
		'after_title'   => '</h2></div>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Slider News Left Sidebar', 'magazine-palace-pro' ),
		'id'            => 'slider-left-sidebar',
		'description'   => esc_html__( 'Add widgets here for left section.', 'magazine-palace-pro' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget-header"><h2 class="widget-title">',
		'after_title'   => '</h2></div>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Slider News Right Sidebar', 'magazine-palace-pro' ),
		'id'            => 'slider-news-right-sidebar',
		'description'   => esc_html__( 'Add widgets here for right section.', 'magazine-palace-pro' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget-header"><h2 class="widget-title">',
		'after_title'   => '</h2></div>',
	) );


	register_sidebar( array(
		'name'          => esc_html__( 'Home Right Sidebar', 'magazine-palace-pro' ),
		'id'            => 'home-right-sidebar',
		'description'   => esc_html__( 'Add widgets here for right section.', 'magazine-palace-pro' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget-header"><h2 class="widget-title">',
		'after_title'   => '</h2></div>',
	) );

	register_sidebars( 4, array(
		'name'          => esc_html__( 'Optional Sidebar %d', 'magazine-palace-pro' ),
		'id'            => 'optional-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'magazine-palace-pro' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget-header"><h2 class="widget-title">',
		'after_title'   => '</h2></div>',
	) );
}
add_action( 'widgets_init', 'magazine_palace_pro_widgets_init' );


if ( ! function_exists( 'magazine_palace_pro_fonts_url' ) ) :
/**
 * Register Google fonts
 *
 * @return string Google fonts URL for the theme.
 */
function magazine_palace_pro_fonts_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';
	$options = magazine_palace_pro_get_theme_options();


	/* translators: If there are characters in your language that are not supported by Muli, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Playfair Display font: on or off', 'magazine-palace-pro' ) ) {
		$fonts[] = 'Playfair Display:400,500,600,700';
	}

	if ( 'off' !== _x( 'on', 'lato font: on or off', 'magazine-palace-pro' ) ) {
		$fonts[] = 'lato:300,400,700';
	}

	if(!empty( $options['theme_head_typography'] )){
		$fonts[] =  str_replace("+", " ", $options['theme_head_typography']).':400,700';
	}

	if(!empty( $options['theme_menu_typography'] )){
		$fonts[] =  str_replace("+", " ", $options['theme_menu_typography']).':400,700';
	}

	if(!empty( $options['theme_site_title_typography'] )){
		$fonts[] =  str_replace("+", " ", $options['theme_site_title_typography']).':400,700';
	}

	if(!empty( $options['theme_site_description_typography'] )){
		$fonts[] =  str_replace("+", " ", $options['theme_site_description_typography']).':400,700';
	}
	
	if(!empty( $options['theme_body_typography'] )){
		$fonts[] = str_replace("+", " ", $options['theme_body_typography']).':400,700';
	}

	if(!empty( $options['theme_btn_label_typography'] )){
		$fonts[] = str_replace("+", " ", $options['theme_btn_label_typography']).':400,700';
	}



	$query_args = array(
		'family' => urlencode( implode( '|', $fonts ) ),
		'subset' => urlencode( $subsets ),
	);

	if ( $fonts ) {
		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}

	return esc_url_raw( $fonts_url );
}
endif;

/**
 * Add preconnect for Google Fonts.
 *
 * @since Magazine Palace Pro 1.0.0
 *
 * @param array  $urls           URLs to print for resource hints.
 * @param string $relation_type  The relation type the URLs are printed.
 * @return array $urls           URLs to print for resource hints.
 */
function magazine_palace_pro_resource_hints( $urls, $relation_type ) {
	if ( wp_style_is( 'magazine-palace-pro-fonts', 'queue' ) && 'preconnect' === $relation_type ) {
		$urls[] = array(
			'href' => 'https://fonts.gstatic.com',
			'crossorigin',
		);
	}

	return $urls;
}
add_filter( 'wp_resource_hints', 'magazine_palace_pro_resource_hints', 10, 2 );

/**
 * Enqueue scripts and styles.
 */
function magazine_palace_pro_scripts() {
	$options = magazine_palace_pro_get_theme_options();
	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'magazine-palace-pro-fonts', wptt_get_webfont_url( magazine_palace_pro_fonts_url() ), array(), null );

	// slick
	wp_enqueue_style( 'slick', get_template_directory_uri() . '/assets/css/slick' . magazine_palace_pro_min() . '.css' );

	// slick theme
	wp_enqueue_style( 'slick-theme', get_template_directory_uri() . '/assets/css/slick-theme' . magazine_palace_pro_min() . '.css' );

	// font awesome
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/css/font-awesome' . magazine_palace_pro_min() . '.css' );

	//magnific-popup
	wp_enqueue_style( 'magnific-popup', get_template_directory_uri() . '/assets/css/magnific-popup' . magazine_palace_pro_min() . '.css' );

	wp_enqueue_style( 'magazine-palace-pro-style', get_stylesheet_uri() );

	// Load the colorscheme.
	$color_scheme = $options['colorscheme'];
	if ( ! in_array( $color_scheme, array( 'default', 'custom' ) ) ) {
		wp_enqueue_style( 'magazine-palace-pro-colors', get_template_directory_uri() . '/assets/css/' . esc_attr( $color_scheme ) . magazine_palace_pro_min() .'.css', array( 'magazine-palace-pro-style' ), '1.0' );
	}
	
	// Load the html5 shiv.
	wp_enqueue_script( 'magazine-palace-pro-html5', get_template_directory_uri() . '/assets/js/html5' . magazine_palace_pro_min() . '.js', array(), '3.7.3' );
	wp_script_add_data( 'magazine-palace-pro-html5', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'magazine-palace-pro-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix' . magazine_palace_pro_min() . '.js', array(), '20160412', true );

	wp_enqueue_script( 'magazine-palace-pro-navigation', get_template_directory_uri() . '/assets/js/navigation' . magazine_palace_pro_min() . '.js', array(), '20151215', true );
	
	$magazine_palace_pro_l10n = array(
		'quote'          => magazine_palace_pro_get_svg( array( 'icon' => 'quote-right' ) ),
		'expand'         => esc_html__( 'Expand child menu', 'magazine-palace-pro' ),
		'collapse'       => esc_html__( 'Collapse child menu', 'magazine-palace-pro' ),
		'icon'           => magazine_palace_pro_get_svg( array( 'icon' => 'down', 'fallback' => true ) ),
	);
	
	wp_localize_script( 'magazine-palace-pro-navigation', 'magazine_palace_pro_l10n', $magazine_palace_pro_l10n );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_enqueue_script( 'jquery-slick', get_template_directory_uri() . '/assets/js/slick' . magazine_palace_pro_min() . '.js' , array( 'jquery' ), '', true );

	wp_enqueue_script( 'magnific-popup', get_template_directory_uri() . '/assets/js/jquery.magnific-popup' . magazine_palace_pro_min() . '.js' , array( 'jquery' ), '', true );

	wp_enqueue_script( 'theia-sticky', get_template_directory_uri() . '/assets/js/theia-sticky-sidebar' . magazine_palace_pro_min() . '.js' , array( 'jquery' ), '', true );

	wp_enqueue_script( 'jquery-marquee', get_template_directory_uri() . '/assets/js/jquery-marquee' . magazine_palace_pro_min() . '.js' , array( 'jquery' ), '', true );

	wp_enqueue_script( 'packery-pkgd', get_template_directory_uri() . '/assets/js/packery-pkgd' . magazine_palace_pro_min() . '.js' , array( 'jquery' ), '', true );

	wp_enqueue_style( 'magazine-palace-pro-blocks', get_template_directory_uri() . '/assets/css/blocks' . magazine_palace_pro_min() . '.css' );

	wp_enqueue_script( 'custom-js', get_template_directory_uri() . '/assets/js/custom' . magazine_palace_pro_min() . '.js', array(), '', true );

	wp_localize_script( 'custom-js', 'magazine_palace_pro', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ) ) );    

	if ( 'infinite' == $options['pagination_type'] ) {
		// infinite scroll js
		wp_enqueue_script( 'magazine-palace-pro-infinite-scroll', get_template_directory_uri() . '/assets/js/infinite-scroll' . magazine_palace_pro_min() . '.js', array( 'jquery' ), '', true );
	}
}
add_action( 'wp_enqueue_scripts', 'magazine_palace_pro_scripts' );

/**
 * Enqueue editor styles for Gutenberg
 *
 * @since Magazine Palace Pro 1.0.0
 */
function magazine_palace_pro_block_editor_styles() {
	// Block styles.
	wp_enqueue_style( 'magazine-palace-pro-block-editor-style', get_theme_file_uri( '/assets/css/editor-blocks' . magazine_palace_pro_min() . '.css' ) );
	// Add custom fonts.
	wp_enqueue_style( 'magazine-palace-pro-fonts', wptt_get_webfont_url( magazine_palace_pro_fonts_url() ), array(), null );
}
add_action( 'enqueue_block_editor_assets', 'magazine_palace_pro_block_editor_styles' );

function magazine_palace_pro_video_url_meta_box() {

    add_meta_box(
        'video Code',
        __( 'Youtube Video Code', 'magazine-palace-pro' ),
        'magazine_palace_pro_video_url_meta_box_callback',
        'post'
    );
}

add_action( 'add_meta_boxes', 'magazine_palace_pro_video_url_meta_box' );

function magazine_palace_pro_video_url_meta_box_callback( $post ) {

    // Add a nonce field so we can check for it later.
    wp_nonce_field( 'magazine_palace_pro_video_url_nonce', 'magazine_palace_pro_video_url_nonce' );

    $value = get_post_meta( $post->ID, '_magazine_palace_pro_youtube_video_code', true );

    echo '<textarea style="width:100%" id="magazine_palace_pro_video_url" name="magazine_palace_pro_video_url">' . esc_attr( $value ) . '</textarea>';
}

/**
 * When the post is saved, saves our custom data.
 *
 * @param int $post_id
 */
function save_magazine_palace_pro_youtube_video_code_meta_box_data( $post_id ) {

    // Check if our nonce is set.
    if ( ! isset( $_POST['magazine_palace_pro_video_url_nonce'] ) ) {
        return;
    }

    // Verify that the nonce is valid.
    if ( ! wp_verify_nonce( $_POST['magazine_palace_pro_video_url_nonce'], 'magazine_palace_pro_video_url_nonce' ) ) {
        return;
    }

    // If this is an autosave, our form has not been submitted, so we don't want to do anything.
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return;
    }

    // Check the user's permissions.
    if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {

        if ( ! current_user_can( 'edit_page', $post_id ) ) {
            return;
        }

    }
    else {

        if ( ! current_user_can( 'edit_post', $post_id ) ) {
            return;
        }
    }

    /* OK, it's safe for us to save the data now. */

    // Make sure that it is set.
    if ( ! isset( $_POST['magazine_palace_pro_video_url'] ) ) {
        return;
    }

    // Sanitize user input.
    $my_data = sanitize_text_field( $_POST['magazine_palace_pro_video_url'] );

    // Update the meta field in the database.
    update_post_meta( $post_id, '_magazine_palace_pro_youtube_video_code', $my_data );
}

add_action( 'save_post', 'save_magazine_palace_pro_youtube_video_code_meta_box_data' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load core file
 */
require get_template_directory() . '/inc/core.php';
