<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Magazine Palace Pro
 * @since Magazine Palace Pro 1.0.0
 */

if ( ! function_exists( 'magazine_palace_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Magazine Palace Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function magazine_palace_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'magazine_palace_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'magazine_palace_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Magazine Palace Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function magazine_palace_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'magazine_palace_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'magazine_palace_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Magazine Palace Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function magazine_palace_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'magazine_palace_pro_theme_options[pagination_enable]' )->value();
	}
endif;

// Instagarm
if ( ! function_exists( 'magazine_palace_pro_is_instagram_section_enable' ) ) :

	function magazine_palace_pro_is_instagram_section_enable( $control ) {
		return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[instagram_section_enable]' )->value() );
	}
endif;

// topbar

if ( ! function_exists( 'magazine_palace_pro_is_topbar_two_enable' ) ) :

	function magazine_palace_pro_is_topbar_two_enable( $control ) {
		return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[topbar_design]' )->value() == 'topbar-two' );
	}
endif;

if ( ! function_exists( 'magazine_palace_pro_is_topbar_one_enable' ) ) :

	function magazine_palace_pro_is_topbar_one_enable( $control ) {
		return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[topbar_design]' )->value() == 'topbar-one' );
	}
endif;

if ( ! function_exists( 'magazine_palace_pro_is_header_one_enable' ) ) :

	function magazine_palace_pro_is_header_one_enable( $control ) {
		return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[header_design]' )->value() == 'header-one' );
	}
endif;

if ( ! function_exists( 'magazine_palace_pro_is_header_three_enable' ) ) :

	function magazine_palace_pro_is_header_three_enable( $control ) {
		return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[header_design]' )->value() == 'header-three' );
	}
endif;


/**
 * Check if topbar section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[topbar_section_enable]' )->value() );
}


/**
 * Front Page Active Callbacks
 */

/**
 * Check if tag section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_tag_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[tag_section_enable]' )->value() );
}

/**
 * Check if breakingnews section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_breakingnews_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[breakingnews_section_enable]' )->value() );
}

/**
 * Check if breaking news slider section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_breakingnews_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if breakingnews section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_breakingnews_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[breakingnews_content_type]' )->value();
	return magazine_palace_pro_is_breakingnews_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if breakingnews section content type is page.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_breakingnews_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[breakingnews_content_type]' )->value();
	return magazine_palace_pro_is_breakingnews_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if breakingnews section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_breakingnews_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[breakingnews_content_type]' )->value();
	return magazine_palace_pro_is_breakingnews_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if Featured Slider section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_slider_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[slider_news_section_enable]' )->value() );
}


/**
 * Check if related section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_slider_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[slider_news_content_type]' )->value();
	return magazine_palace_pro_is_slider_news_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if related section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_slider_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[slider_news_content_type]' )->value();
	return magazine_palace_pro_is_slider_news_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if two_section section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_two_section_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[two_section_section_enable]' )->value() );
}

/**
 * Check if two_section section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_two_section_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[two_section_grid_post_content_type]' )->value();
	return magazine_palace_pro_is_two_section_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if two_section section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_two_section_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[two_section_grid_post_content_type]' )->value();
	return magazine_palace_pro_is_two_section_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if multi_post section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_multi_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[multi_post_section_enable]' )->value() );
}

/**
 * Check if multi_post section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_multi_post_col1_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[multi_post_col1_content_type]' )->value();
	return magazine_palace_pro_is_multi_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if multi_post section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_multi_post_col1_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[multi_post_col1_content_type]' )->value();
	return magazine_palace_pro_is_multi_post_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if multi_post section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_multi_post_col2_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[multi_post_col2_content_type]' )->value();
	return magazine_palace_pro_is_multi_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if multi_post section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_multi_post_col2_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[multi_post_col2_content_type]' )->value();
	return magazine_palace_pro_is_multi_post_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if multi_post section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_multi_post_col3_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[multi_post_col3_content_type]' )->value();
	return magazine_palace_pro_is_multi_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if multi_post section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_multi_post_col3_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[multi_post_col3_content_type]' )->value();
	return magazine_palace_pro_is_multi_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if post carousel section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_post_carousel_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[post_carousel_section_enable]' )->value() );
}


/**
 * Check if related section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_post_carousel_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[post_carousel_content_type]' )->value();
	return magazine_palace_pro_is_post_carousel_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if related section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_post_carousel_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[post_carousel_content_type]' )->value();
	return magazine_palace_pro_is_post_carousel_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if have missed section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_have_missed_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[have_missed_section_enable]' )->value() );
}


/**
 * Check if related section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_have_missed_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[have_missed_content_type]' )->value();
	return magazine_palace_pro_is_have_missed_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if related section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_have_missed_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[have_missed_content_type]' )->value();
	return magazine_palace_pro_is_have_missed_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if main slider section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_main_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[main_slider_section_enable]' )->value() );
}

/**
 * Check if latest_post section content type is page.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_main_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[main_slider_content_type]' )->value();
	return magazine_palace_pro_is_main_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest_post section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_main_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[main_slider_content_type]' )->value();
	return magazine_palace_pro_is_main_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest_post section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_main_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[main_slider_content_type]' )->value();
	return magazine_palace_pro_is_main_slider_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if featured category section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_featured_category_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[featured_category_section_enable]' )->value() );
}

/**
 * Check if featured_post section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_featured_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[featured_post_section_enable]' )->value() );
}

/**
 * Check if featured_post section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_featured_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[featured_post_content_type]' )->value();
	return magazine_palace_pro_is_featured_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_post section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_featured_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[featured_post_content_type]' )->value();
	return magazine_palace_pro_is_featured_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog_slider section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_blog_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[blog_slider_section_enable]' )->value() );
}

/**
 * Check if blog_slider section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_blog_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[blog_slider_content_type]' )->value();
	return magazine_palace_pro_is_blog_slider_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if blog_slider section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_blog_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[blog_slider_content_type]' )->value();
	return magazine_palace_pro_is_blog_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if Post Grid section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_post_grid_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[post_grid_section_enable]' )->value() );
}


/**
 * Check if related section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_post_grid_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[post_grid_content_type]' )->value();
	return magazine_palace_pro_is_post_grid_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if related section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_post_grid_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[post_grid_content_type]' )->value();
	return magazine_palace_pro_is_post_grid_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if Banner Post section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_banner_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[banner_post_section_enable]' )->value() );
}


/**
 * Check if related section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_banner_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[banner_post_content_type]' )->value();
	return magazine_palace_pro_is_banner_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if related section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_banner_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[banner_post_content_type]' )->value();
	return magazine_palace_pro_is_banner_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if Banner Post section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_sport_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[sport_post_section_enable]' )->value() );
}


/**
 * Check if related section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_sport_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[sport_post_content_type]' )->value();
	return magazine_palace_pro_is_sport_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if related section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_sport_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[sport_post_content_type]' )->value();
	return magazine_palace_pro_is_sport_post_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if Featured Slider section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_featured_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[featured_slider_section_enable]' )->value() );
}


/**
 * Check if related section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_featured_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[featured_slider_content_type]' )->value();
	return magazine_palace_pro_is_featured_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if related section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_featured_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[featured_slider_content_type]' )->value();
	return magazine_palace_pro_is_featured_slider_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if two col section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_two_col_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[two_col_section_enable]' )->value() );
}


/**
 * Check if related section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_two_col_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[two_col_content_type]' )->value();
	return magazine_palace_pro_is_two_col_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if related section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_two_col_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[two_col_content_type]' )->value();
	return magazine_palace_pro_is_two_col_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if Three col slider section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_three_col_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[three_col_slider_section_enable]' )->value() );
}


/**
 * Check if related section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_three_col_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[three_col_slider_content_type]' )->value();
	return magazine_palace_pro_is_three_col_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if related section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_three_col_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[three_col_slider_content_type]' )->value();
	return magazine_palace_pro_is_three_col_slider_section_enable( $control ) && ( 'category' == $content_type );
}



/**
 * Check if latest_post section is enabled.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_latest_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazine_palace_pro_theme_options[latest_post_section_enable]' )->value() );
}


/**
 * Check if latest_post section content type is post.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_latest_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[latest_post_content_type]' )->value();
	return magazine_palace_pro_is_latest_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest_post section content type is category.
 *
 * @since Magazine Palace Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazine_palace_pro_is_latest_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazine_palace_pro_theme_options[latest_post_content_type]' )->value();
	return magazine_palace_pro_is_latest_post_section_enable( $control ) && ( 'category' == $content_type );
}


