<?php
/**
 * Magazine Palace Pro Customizer.
 *
 * @package Theme Palace
 * @subpackage Magazine Palace Pro
 * @since Magazine Palace Pro 1.0.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function magazine_palace_pro_customize_register( $wp_customize ) {
	$options = magazine_palace_pro_get_theme_options();

	// Load custom control functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load partial callback functions.
	require get_template_directory() . '/inc/customizer/partial.php';


	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	// Remove the core header textcolor control, as it shares the main text color.
	$wp_customize->remove_control( 'header_textcolor' );

	// Header title color setting and control.
	$wp_customize->add_setting( 'magazine_palace_pro_theme_options[header_title_color]', array(
		'default'           => $options['header_title_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'magazine_palace_pro_theme_options[header_title_color]', array(
		'priority'			=> 5,
		'label'             => esc_html__( 'Header Title Color', 'magazine-palace-pro' ),
		'section'           => 'colors',
	) ) );

	// Header tagline color setting and control.
	$wp_customize->add_setting( 'magazine_palace_pro_theme_options[header_tagline_color]', array(
		'default'           => $options['header_tagline_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'magazine_palace_pro_theme_options[header_tagline_color]', array(
		'priority'			=> 6,
		'label'             => esc_html__( 'Header Tagline Color', 'magazine-palace-pro' ),
		'section'           => 'colors',
	) ) );

	// Site identity extra options.
	$wp_customize->add_setting( 'magazine_palace_pro_theme_options[header_txt_logo_extra]', array(
		'default'           => $options['header_txt_logo_extra'],
		'sanitize_callback' => 'magazine_palace_pro_sanitize_select',
		'transport'			=> 'refresh'
	) );

	$wp_customize->add_control( 'magazine_palace_pro_theme_options[header_txt_logo_extra]', array(
		'priority'			=> 50,
		'type'				=> 'radio',
		'label'             => esc_html__( 'Site Identity Extra Options', 'magazine-palace-pro' ),
		'section'           => 'title_tagline',
		'choices'				=> array( 
			'hide-all'     => esc_html__( 'Hide All', 'magazine-palace-pro' ),
			'show-all'     => esc_html__( 'Show All', 'magazine-palace-pro' ),
			'title-only'   => esc_html__( 'Title Only', 'magazine-palace-pro' ),
			'tagline-only' => esc_html__( 'Tagline Only', 'magazine-palace-pro' ),
			'logo-title'   => esc_html__( 'Logo + Title', 'magazine-palace-pro' ),
			'logo-tagline' => esc_html__( 'Logo + Tagline', 'magazine-palace-pro' ),
			)
	) );

	/**
	 * Theme color.
	 */
	$wp_customize->add_setting( 'magazine_palace_pro_theme_options[theme_color]', array(
		'default'           => $options['theme_color'],
		'sanitize_callback' => 'magazine_palace_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'magazine_palace_pro_theme_options[theme_color]', array(
		'type'    => 'radio',
		'label'    => esc_html__( 'Theme Color', 'magazine-palace-pro' ),
		'choices'  => array(
            'dark-version'   => esc_html__( 'Dark Version', 'magazine-palace-pro' ),
            'lite-version'   => esc_html__( 'Lite Version', 'magazine-palace-pro' ),
		),
		'section'  => 'colors',
	) );

	/**
	 * Custom colors.
	 */
	$wp_customize->add_setting( 'magazine_palace_pro_theme_options[colorscheme]', array(
		'default'           => $options['colorscheme'],
		'sanitize_callback' => 'magazine_palace_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'magazine_palace_pro_theme_options[colorscheme]', array(
		'type'    => 'radio',
		'label'    => esc_html__( 'Color Scheme', 'magazine-palace-pro' ),
		'choices'  => array(
            'default'   => esc_html__( 'Default', 'magazine-palace-pro' ),
            'blue'      => esc_html__( 'Blue', 'magazine-palace-pro' ),
            'green'     => esc_html__( 'Green', 'magazine-palace-pro' ),
            'red'       => esc_html__( 'Dark Red', 'magazine-palace-pro' ),
            'yellow'    => esc_html__( 'Yellow', 'magazine-palace-pro' ),
            'custom'    => esc_html__( 'Custom', 'magazine-palace-pro' ),
		),
		'section'  => 'colors',
	) );

	$wp_customize->add_setting( 'magazine_palace_pro_theme_options[colorscheme_hue]', array(
		'default'           => $options['colorscheme_hue'],
		'sanitize_callback' => 'sanitize_hex_color', // The hue is stored as a positive integer.
	) );


	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'magazine_palace_pro_theme_options[colorscheme_hue]', array(
		'section'  => 'colors',
	) ) );

	// Add panel for common theme options
	$wp_customize->add_panel( 'magazine_palace_pro_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','magazine-palace-pro' ),
	    'description'=> esc_html__( 'Magazine Palace Pro Theme Options.', 'magazine-palace-pro' ),
	    'priority'   => 150,
	) );

	// topbar
	require get_template_directory() . '/inc/customizer/theme-options/topbar.php';
	require get_template_directory() . '/inc/customizer/theme-options/style/topbar.php';

	// header
	require get_template_directory() . '/inc/customizer/theme-options/header.php';
	require get_template_directory() . '/inc/customizer/theme-options/style/header.php';

	// page banner
	require get_template_directory() . '/inc/customizer/theme-options/page-banner.php';

	// loader
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// typography
	require get_template_directory() . '/inc/customizer/theme-options/typography.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/excerpt.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/archive.php';
	require get_template_directory() . '/inc/customizer/theme-options/style/archive.php';
	
	// load single post option
	require get_template_directory() . '/inc/customizer/theme-options/single-posts.php';
	require get_template_directory() . '/inc/customizer/theme-options/style/single-post.php';

	require get_template_directory() . '/inc/customizer/theme-options/style/widget.php';

	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';
	require get_template_directory() . '/inc/customizer/theme-options/style/footer.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';

	// Add panel for front page theme options.
	$wp_customize->add_panel( 'magazine_palace_pro_front_page_panel' , array(
	    'title'      => esc_html__( 'Front Page','magazine-palace-pro' ),
	    'description'=> esc_html__( 'Front Page Theme Options.', 'magazine-palace-pro' ),
	    'priority'   => 140,
	) );

	require get_template_directory() . '/inc/customizer/sections/home-layout.php';

	// load tag option
	require get_template_directory() . '/inc/customizer/sections/tag.php';
	require get_template_directory() . '/inc/customizer/sections/style/tag.php';

	// load breakingnews option
	require get_template_directory() . '/inc/customizer/sections/breakingnews.php';	
	require get_template_directory() . '/inc/customizer/sections/style/breakingnews.php';	

	// load slider news option
	require get_template_directory() . '/inc/customizer/sections/slider-news.php';	
	require get_template_directory() . '/inc/customizer/sections/style/slider-news.php';


	// load magazine_palace_pro_two_section_section option
	require get_template_directory() . '/inc/customizer/sections/two-section.php';	
	require get_template_directory() . '/inc/customizer/sections/style/two-section.php';

	// load multi-post option
	require get_template_directory() . '/inc/customizer/sections/multi-post.php';
	require get_template_directory() . '/inc/customizer/sections/style/multi-post.php';

	// load magazine_palace_pro_post_carousel_section option
	require get_template_directory() . '/inc/customizer/sections/post-carousel.php';
	require get_template_directory() . '/inc/customizer/sections/style/post-carousel.php';

	// load magazine_palace_pro_post_carousel_section option
	require get_template_directory() . '/inc/customizer/sections/have-missed.php';
	require get_template_directory() . '/inc/customizer/sections/style/have-missed.php';

	// load featured post option
	require get_template_directory() . '/inc/customizer/sections/featured-post.php';
	require get_template_directory() . '/inc/customizer/sections/style/featured-post.php';

	// load main slider option
	require get_template_directory() . '/inc/customizer/sections/main-slider.php';
	require get_template_directory() . '/inc/customizer/sections/style/main-slider.php';

	// load featured category option
	require get_template_directory() . '/inc/customizer/sections/featured-category.php';
	require get_template_directory() . '/inc/customizer/sections/style/featured-category.php';

	// load blog slider option
	require get_template_directory() . '/inc/customizer/sections/blog-slider.php';
	require get_template_directory() . '/inc/customizer/sections/style/blog-slider.php';

	// load post grid option
	require get_template_directory() . '/inc/customizer/sections/post-grid.php';
	require get_template_directory() . '/inc/customizer/sections/style/post-grid.php';

	// load banner post option
	require get_template_directory() . '/inc/customizer/sections/banner-post.php';
	require get_template_directory() . '/inc/customizer/sections/style/banner-post.php';

	// load sport post option
	require get_template_directory() . '/inc/customizer/sections/sport-post.php';
	require get_template_directory() . '/inc/customizer/sections/style/sport-post.php';

	// load featured slider option
	require get_template_directory() . '/inc/customizer/sections/featured-slider.php';
	require get_template_directory() . '/inc/customizer/sections/style/featured-slider.php';

	// load three col slider option
	require get_template_directory() . '/inc/customizer/sections/three-col-slider.php';
	require get_template_directory() . '/inc/customizer/sections/style/three-col-slider.php';

	// load two col option
	require get_template_directory() . '/inc/customizer/sections/two-col.php';
	require get_template_directory() . '/inc/customizer/sections/style/two-col.php';


	// load latest post option
	require get_template_directory() . '/inc/customizer/sections/latest-post.php';
	require get_template_directory() . '/inc/customizer/sections/style/latest-post.php';

	// load instagram option
	require get_template_directory() . '/inc/customizer/sections/instagram.php';
	// require get_template_directory() . '/inc/customizer/sections/style/instagram.php';

	
	
}
add_action( 'customize_register', 'magazine_palace_pro_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function magazine_palace_pro_customize_preview_js() {
	wp_enqueue_script( 'magazine-palace-pro-customizer', get_template_directory_uri() . '/assets/js/customizer' . magazine_palace_pro_min() . '.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'magazine_palace_pro_customize_preview_js' );

/**
 * Load dynamic logic for the customizer controls area.
 */
function magazine_palace_pro_customize_control_js() {
	
	// Choose from select jquery.
	wp_enqueue_style( 'chosen-css', get_template_directory_uri() . '/assets/css/chosen' . magazine_palace_pro_min() . '.css' );
	wp_enqueue_script( 'jquery-chosen', get_template_directory_uri() . '/assets/js/chosen.jquery' . magazine_palace_pro_min() . '.js', array( 'jquery' ), '1.4.2', true );

	wp_enqueue_style( 'magazine-palace-pro-customize-controls-css', get_template_directory_uri() . '/assets/css/customize-controls' . magazine_palace_pro_min() . '.css' );
	wp_enqueue_script( 'magazine-palace-pro-customize-controls', get_template_directory_uri() . '/assets/js/customize-controls' . magazine_palace_pro_min() . '.js', array(), '1.0', true );
	$magazine_palace_pro_reset_data = array(
		'reset_message' => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'magazine-palace-pro' )
	);
	// Send list of color variables as object to custom customizer js
	wp_localize_script( 'magazine-palace-pro-customize-controls', 'magazine_palace_pro_reset_data', $magazine_palace_pro_reset_data );

	$theme_path_url = array( 'url' => get_theme_file_uri() );

	wp_localize_script( 'magazine-palace-pro-customize-controls', 'theme_url', $theme_path_url );
}
add_action( 'customize_controls_enqueue_scripts', 'magazine_palace_pro_customize_control_js' );

if ( !function_exists( 'magazine_palace_pro_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Magazine Palace Pro 1.0.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function magazine_palace_pro_reset_options() {
		$options = magazine_palace_pro_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'magazine_palace_pro_theme_options', array() );
			// Reset custom header and backgrounds.
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
			remove_theme_mod( 'header_textcolor' );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'magazine_palace_pro_reset_options' );
