<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Magazine Palace Pro
 * @since Magazine Palace Pro 1.0.0
 * @return array An array of default values
 */

function magazine_palace_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$magazine_palace_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#e5383e',
		'colorscheme'					=> 'default',
		'theme_color'					=> 'lite-version',
		'header_overlay_color'			=> '#000',
		'header_overlay'				=> 5,
		'home_layout'					=> 'default-design',
		'homepage_section_gap'			=> 10,
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		'bg_image'						=> '',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'nav_search_enable'				=> true,
		'widget_enable_sticky_homepage' => false,
		'transparent_menu' 				=> false,
		'widget_enable_sticky' 			=> false,


		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Read More', 'magazine-palace-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'magazine-palace-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'magazine-palace-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'magazine-palace-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,
		'footer_wrapper_enable'			=> false,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'homepage_sortable' 						=> 'tag,breakingnews,slider_news,two_section,multi_post,post_carousel,have_missed,featured_post,main_slider,featured_category,blog_slider,main_content,instagram',
		'homepage_inner_sortable'					=> 'post_grid,banner_post,sport_post,featured_slider,three_col_slider,two_col,latest_post',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'magazine-palace-pro' ),
		'hide_category'					=> false,
		'hide_author'					=> false,
		'hide_date'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,
		'single_post_hide_post_title'   => false,
		'single_post_hide_featured_image'   => false,

		'page_banner_wrapper_enable'	=> false,
		'page_banner_breadcrumb_enable'	=> false,
		'page_banner_header_image_enable'	=> false,

		/* Front Page */

		// Tag
		'tag_section_enable'			=> false,
		'tag_title'						=> esc_html__('Popular Tags', 'magazine-palace-pro' ),


		// Topbar
		'topbar_section_enable'			=> false,
		'topbar_btn_text'				=> esc_html__('Live', 'magazine-palace-pro' ),
		'topbar_date_icon_enable'		=> false,
		'topbar_design'					=> 'topbar-one',
		'topbar_section_wrapper_enable'	=> false,
		'topbar_btn_url'				=> '#',

		// Header
		'header_design'		=> 'header-one',
		'header_home_icon_enable' => true,
		'header_search_enable'	=> true,
		'header_wrapper_enable'	=> false,

		// Breaking News
		'breakingnews_section_enable'			=> true,
		'breakingnews_featured_image_enable'	=> false,
		'breakingnews_content_type'				=> 'post',
		'breakingnews_count'					=> 3,
		'breakingnews_title'					=> esc_html__( 'Breaking News', 'magazine-palace-pro' ),
		'breaking_news_icon'					=> 'wave',


		// two_section
		'two_section_title_one'					=> esc_html__( 'Slider Post', 'magazine-palace-pro' ),
		'two_section_title_two'					=> esc_html__( 'Grid Post', 'magazine-palace-pro' ),
		'two_section_section_enable'			=> true,
		'two_section_grid_post_content_type'	=> 'post',
		'two_section_auto_play'					=> false,


		//multi post 
		'multi_post_section_enable'		=> true,
		'multi_post_col1_title'			=> esc_html__( 'Column One', 'magazine-palace-pro' ),
		'multi_post_col1_count'			=> 5,
		'multi_post_col1_content_type'	=> 'post',
		'multi_post_col2_title'			=> esc_html__( 'Column Two', 'magazine-palace-pro' ),
		'multi_post_col2_count'			=> 5,
		'multi_post_col2_content_type'	=> 'post',
		'multi_post_col3_title'			=> esc_html__( 'Column Three', 'magazine-palace-pro' ),
		'multi_post_col3_count'			=> 5,
		'multi_post_col3_content_type'	=> 'post',

		// post_carousel
		'post_carousel_section_enable'		=> true,
		'post_carousel_autoplay_enable'		=> true,
		'post_carousel_content_type'		=> 'post',
		'post_carousel_count'				=> 4,
		'post_carousel_title'				=> esc_html__( 'Post Carousel', 'magazine-palace-pro' ),

		// have_missed
		'have_missed_section_enable'		=> true,
		'have_missed_autoplay_enable'		=> true,
		'have_missed_content_type'		=> 'post',
		'have_missed_count'				=> 4,
		'have_missed_title'				=> esc_html__( 'Have Missed', 'magazine-palace-pro' ),

		// featured_post
		'featured_post_section_enable'		=> true,
		'featured_post_autoplay_enable'		=> true,
		'featured_post_content_type'		=> 'post',
		'featured_post_count'				=> 4,
		'featured_post_title'				=> esc_html__( 'Featured Post', 'magazine-palace-pro' ),

		// main_slider
		'main_slider_section_enable'		=> true,
		'main_slider_section_margin_top_enable' => true,
		'main_slider_autoplay_enable'		=> true,
		'main_slider_content_type'			=> 'post',
		'main_slider_count'					=> 4,
		'main_slider_btn_title'					=> esc_html__( 'Read More', 'magazine-palace-pro' ),

		// featured_category
		'featured_category_section_enable'		=> true,
		'featured_category_count'					=> 3,

		// blog_slider
		'blog_slider_section_enable'		=> true,
		'blog_slider_autoplay_enable'		=> true,
		'blog_slider_content_type'		=> 'post',
		'blog_slider_count'				=> 4,

		// post_grid
		'post_grid_section_enable'		=> true,
		'post_grid_content_type'		=> 'post',
		'post_grid_count'				=> 4,
		'post_grid_title'				=> esc_html__( 'Post Grid', 'magazine-palace-pro' ),

		// banner_post
		'banner_post_section_enable'		=> true,
		'banner_post_content_type'			=> 'post',
		'banner_post_title'					=> esc_html__( 'Banner Post', 'magazine-palace-pro' ),

		// sport_post
		'sport_post_section_enable'		=> true,
		'sport_post_content_type'			=> 'post',
		'sport_post_title'					=> esc_html__( 'Sport Post', 'magazine-palace-pro' ),

		// featured_slider
		'featured_slider_section_enable'		=> true,
		'featured_slider_autoplay_enable'		=> true,
		'featured_slider_content_type'		=> 'post',
		'featured_slider_count'				=> 4,
		'featured_slider_title'				=> esc_html__( 'Featured Slider', 'magazine-palace-pro' ),

		// slider_news
		'slider_news_section_enable'		=> true,
		'slider_news_autoplay_enable'		=> true,
		'slider_news_content_type'		=> 'post',
		'slider_news_count'				=> 4,
		'slider_news_title'				=> esc_html__( 'Slider News', 'magazine-palace-pro' ),

		// three_col_slider
		'three_col_slider_section_enable'		=> true,
		'three_col_slider_autoplay_enable'		=> true,
		'three_col_slider_content_type'		=> 'post',
		'three_col_slider_count'				=> 4,
		'three_col_slider_title'				=> esc_html__( 'Three Column', 'magazine-palace-pro' ),

		// two_col
		'two_col_section_enable'		=> true,
		'two_col_content_type'		=> 'post',
		'two_col_count'				=> 4,
		'two_col_title'				=> esc_html__( 'Two Column', 'magazine-palace-pro' ),

		'main_content_section_enable'			=> true,

		// Latest post
		'latest_post_title'				=> esc_html__( 'Latest News', 'magazine-palace-pro' ),
		'latest_post_btn_title'				=> esc_html__( 'Read More', 'magazine-palace-pro' ),
		'latest_post_section_enable' => true,
		'latest_post_content_type'	=> 'post',
		'latest_post_count'			=> 4,
		'latest_post_content_excerpt'	=> 10,

		// Instagram
		'instagram_section_enable' => true,
		'instagram_section_wrapper_enable' => false,

	);

	$output = apply_filters( 'magazine_palace_pro_default_theme_options', $magazine_palace_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}