<?php
/**
* Breaking News Section options
*
* @package Theme Palace
* @subpackage Magazine Palace Pro
* @since Magazine Palace Pro 1.0.0
*/

// Add Breaking News section
$wp_customize->add_section( 'magazine_palace_pro_breakingnews_section', array(
	'title'             => esc_html__( 'Breaking News','magazine-palace-pro' ),
	'description'       => esc_html__( 'Breaking News Section options.', 'magazine-palace-pro' ),
	'panel'             => 'magazine_palace_pro_front_page_panel',
	) );

// Breaking News content enable control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[breakingnews_section_enable]', array(
	'default'			=> 	$options['breakingnews_section_enable'],
	'sanitize_callback' => 'magazine_palace_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Magazine_Palace_Pro_Switch_Control( $wp_customize, 'magazine_palace_pro_theme_options[breakingnews_section_enable]', array(
	'label'             => esc_html__( 'Breaking News Section Enable', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_breakingnews_section',
	'on_off_label' 		=> magazine_palace_pro_switch_options(),
	) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'magazine_palace_pro_theme_options[breakingnews_section_enable]',
		array(
			'selector'            => '#magazine_palace_pro_breakingnews_section .tooltiptext',
			'settings'            => 'magazine_palace_pro_theme_options[breakingnews_section_enable]',
		)
	);
}

$wp_customize->add_setting( 
    'magazine_palace_pro_theme_options_breakingnews_setting_style',
    array(
        'sanitize_callback' => 'sanitize_text_field',
    )
);

$wp_customize->add_control( 
    new Magazine_Palace_Pro_Customize_Control_Section_Style( 
    $wp_customize,
    'magazine_palace_pro_theme_options_breakingnews_setting_style',
        array(
            'section'       => 'magazine_palace_pro_breakingnews_section',
            'active_callback' 	=> 'magazine_palace_pro_is_breakingnews_section_enable',
            'choices'  => array(

                'setting'    => array(
                    'name' => esc_html__( 'Setting', 'magazine-palace-pro' ),
                    'section_id' => 'magazine_palace_pro_breakingnews_section',
                ),
                
                'style'    => array(
                    'name' => esc_html__( 'Style', 'magazine-palace-pro' ),
                    'section_id' => 'magazine_palace_pro_breakingnews_section_style',
                ),
            ),
        )
    )
);

$wp_customize->add_setting( 'magazine_palace_pro_theme_options[breakingnews_featured_image_enable]', array(
	'default'			=> 	$options['breakingnews_featured_image_enable'],
	'sanitize_callback' => 'magazine_palace_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Magazine_Palace_Pro_Switch_Control( $wp_customize, 'magazine_palace_pro_theme_options[breakingnews_featured_image_enable]', array(
	'label'             => esc_html__( 'Breaking Featured Image Enable', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_breakingnews_section',
	'active_callback' 	=> 'magazine_palace_pro_is_breakingnews_section_enable',
	'on_off_label' 		=> magazine_palace_pro_switch_options(),
) ) );


// breakingnews title setting and control
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[breakingnews_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['breakingnews_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'magazine_palace_pro_theme_options[breakingnews_title]', array(
	'label'           	=> esc_html__( 'Title', 'magazine-palace-pro' ),
	'section'        	=> 'magazine_palace_pro_breakingnews_section',
	'active_callback' 	=> 'magazine_palace_pro_is_breakingnews_section_enable',
	'type'				=> 'text',
	) );

$wp_customize->add_setting( 'magazine_palace_pro_theme_options[breaking_news_icon]', array(
	'default'           => $options['breaking_news_icon'],
	'sanitize_callback' => 'magazine_palace_pro_sanitize_select',
) );

$wp_customize->add_control( 'magazine_palace_pro_theme_options[breaking_news_icon]', array(
	'type'    => 'radio',
	'label'    => esc_html__( 'Breaking News Icon Type', 'magazine-palace-pro' ),
	'choices'  => array(
        'wave'   => esc_html__( 'Bubble Wave Effect', 'magazine-palace-pro' ),
        'speaker'   => esc_html__( 'Speaker Icon', 'magazine-palace-pro' ),
	),
	'section'  => 'magazine_palace_pro_breakingnews_section',
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[breakingnews_count]', array(
	'default'          	=> $options['breakingnews_count'],
	'sanitize_callback' => 'magazine_palace_pro_sanitize_number_range',
	) );

$wp_customize->add_control( 'magazine_palace_pro_theme_options[breakingnews_count]', array(
	'label'             => esc_html__( 'Number of Breaking News', 'magazine-palace-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_breakingnews_section',
	'active_callback'   => 'magazine_palace_pro_is_breakingnews_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
	) );

// Breaking News content type control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[breakingnews_content_type]', array(
	'default'          	=> $options['breakingnews_content_type'],
	'sanitize_callback' => 'magazine_palace_pro_sanitize_select',
	) );

$wp_customize->add_control( 'magazine_palace_pro_theme_options[breakingnews_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_breakingnews_section',
	'type'				=> 'select',
	'active_callback' 	=> 'magazine_palace_pro_is_breakingnews_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'magazine-palace-pro' ),
		'post' 		=> esc_html__( 'Post', 'magazine-palace-pro' ),
		'category' 	=> esc_html__( 'Category', 'magazine-palace-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['breakingnews_count']; $i++ ) :

// breakingnews pages drop down chooser control and setting
	$wp_customize->add_setting( 'magazine_palace_pro_theme_options[breakingnews_content_page_' . $i . ']', array(
		'sanitize_callback' => 'magazine_palace_pro_sanitize_page',
		) );

$wp_customize->add_control( new Magazine_Palace_Pro_Dropdown_Chooser( $wp_customize, 'magazine_palace_pro_theme_options[breakingnews_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'magazine-palace-pro' ), $i ),
	'section'           => 'magazine_palace_pro_breakingnews_section',
	'choices'			=> magazine_palace_pro_page_choices(),
	'active_callback'	=> 'magazine_palace_pro_is_breakingnews_section_content_page_enable',
	) ) );

// breakingnews posts drop down chooser control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[breakingnews_content_post_' . $i . ']', array(
	'sanitize_callback' => 'magazine_palace_pro_sanitize_page',
	) );

$wp_customize->add_control( new Magazine_Palace_Pro_Dropdown_Chooser( $wp_customize, 'magazine_palace_pro_theme_options[breakingnews_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'magazine-palace-pro' ), $i ),
	'section'           => 'magazine_palace_pro_breakingnews_section',
	'choices'			=> magazine_palace_pro_post_choices(),
	'active_callback'	=> 'magazine_palace_pro_is_breakingnews_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'magazine_palace_pro_theme_options[breakingnews_content_category]', array(
	'sanitize_callback' => 'magazine_palace_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Magazine_Palace_Pro_Dropdown_Taxonomies_Control( $wp_customize,'magazine_palace_pro_theme_options[breakingnews_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'magazine-palace-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_breakingnews_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'magazine_palace_pro_is_breakingnews_section_content_category_enable'
	) ) );

