<?php
/**
 * Featured Category Section options
 *
 * @package Theme Palace
 * @subpackage magazine-palace Pro
 * @since magazine-palace Pro 1.0.0
 */

// Add Featured Category section
$wp_customize->add_section( 'magazine_palace_pro_featured_category_section', array(
    'title'             => esc_html__( 'Featured Category','magazine-palace-pro' ),
    'panel'             => 'magazine_palace_pro_front_page_panel',
) );

// featured_category content enable control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[featured_category_section_enable]', array(
    'default'           =>  $options['featured_category_section_enable'],
    'sanitize_callback' => 'magazine_palace_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Magazine_Palace_Pro_Switch_Control( $wp_customize, 'magazine_palace_pro_theme_options[featured_category_section_enable]', array(
    'label'             => esc_html__( 'Featured Category Section Enable', 'magazine-palace-pro' ),
    'section'           => 'magazine_palace_pro_featured_category_section',
    'on_off_label'      => magazine_palace_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'magazine_palace_pro_theme_options[featured_category_section_enable]',
        array(
            'selector'            => '#magazine_palace_pro_featured_category_section .tooltiptext',
            'settings'            => 'magazine_palace_pro_theme_options[featured_category_section_enable]',
        )
    );
}

$wp_customize->add_setting( 
    'magazine_palace_pro_theme_options_featured_category_setting_style',
    array(
        'sanitize_callback' => 'sanitize_text_field',
    )
);

$wp_customize->add_control( 
    new Magazine_Palace_Pro_Customize_Control_Section_Style( 
    $wp_customize,
    'magazine_palace_pro_theme_options_featured_category_setting_style',
        array(
            'section'       => 'magazine_palace_pro_featured_category_section',
            'active_callback'   => 'magazine_palace_pro_is_featured_category_section_enable',
            'choices'  => array(

                'setting'    => array(
                    'name' => esc_html__( 'Setting', 'magazine-palace-pro' ),
                    'section_id' => 'magazine_palace_pro_featured_category_section',
                ),
                
                'style'    => array(
                    'name' => esc_html__( 'Style', 'magazine-palace-pro' ),
                    'section_id' => 'magazine_palace_pro_featured_category_section_style',
                ),
            ),
        )
    )
);


// featured Category number control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[featured_category_count]', array(
    'default'           => $options['featured_category_count'],
    'sanitize_callback' => 'magazine_palace_pro_sanitize_number_range',
    ) );

$wp_customize->add_control( 'magazine_palace_pro_theme_options[featured_category_count]', array(
    'label'             => esc_html__( 'Number of Posts', 'magazine-palace-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'magazine-palace-pro' ),
    'section'           => 'magazine_palace_pro_featured_category_section',
    'active_callback'   => 'magazine_palace_pro_is_featured_category_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 8,
        'style' => 'width: 100px;'
        ),
    ) );



for ( $i = 1; $i <= $options['featured_category_count']; $i++ ) :

    // Add dropdown category setting and control.
    $wp_customize->add_setting(  'magazine_palace_pro_theme_options[featured_category_content_featured_category_category_'.$i.']', array(
        'sanitize_callback' => 'absint',
    ) ) ;

    $wp_customize->add_control( new Magazine_Palace_Pro_Dropdown_Taxonomies_Control( $wp_customize,'magazine_palace_pro_theme_options[featured_category_content_featured_category_category_'.$i.']', array(
        'label'             => esc_html__( 'Select Featured Category ', 'magazine-palace-pro' ).$i,
        'section'           => 'magazine_palace_pro_featured_category_section',
        'taxonomy'          => 'category',
        'type'              => 'dropdown-taxonomies',
        'active_callback'   => 'magazine_palace_pro_is_featured_category_section_enable'
    ) ) );

    $wp_customize->add_setting( 'magazine_palace_pro_theme_options[featured_category_category_image_' . $i . ']', array(
        'sanitize_callback' => 'magazine_palace_pro_sanitize_image'
    ) );

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'magazine_palace_pro_theme_options[featured_category_category_image_' . $i . ']',
        array(
            'label'             => esc_html__( 'Featured Category Image ', 'magazine-palace-pro' ).$i,
            'section'           => 'magazine_palace_pro_featured_category_section',
            'active_callback'   => 'magazine_palace_pro_is_featured_category_section_enable',
        ) ) );


    // magazine_palace_pro_Customize_Horizontal_Line
    $wp_customize->add_setting('magazine_palace_pro_theme_options[featured_category_content_featured_category_category_seperator_'. $i .']',
        array(
            'sanitize_callback'      => 'magazine_palace_pro_sanitize_html',
        )
    );

    $wp_customize->add_control(new Magazine_Palace_Pro_Customize_Horizontal_Line($wp_customize,
        'magazine_palace_pro_theme_options[featured_category_content_featured_category_category_seperator_'. $i .']',
            array(
                'type'                  =>'hr',
                'section'               =>'magazine_palace_pro_featured_category_section',
                'active_callback'       => 'magazine_palace_pro_is_featured_category_section_enable'
            )
        )
    );
endfor;