<?php
/**
* Featred Post Section options
*
* @package Theme Palace
* @subpackage Magazine Palace Pro
* @since Magazine Palace Pro 1.0.0
*/

// Add Featred Post section
$wp_customize->add_section( 'magazine_palace_pro_featured_post_section', array(
	'title'             => esc_html__( 'Featred Post','magazine-palace-pro' ),
	'description'       => esc_html__( 'Featred Post Section options.', 'magazine-palace-pro' ),
	'panel'             => 'magazine_palace_pro_front_page_panel',
	) );

// Featred Post content enable control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[featured_post_section_enable]', array(
	'default'			=> 	$options['featured_post_section_enable'],
	'sanitize_callback' => 'magazine_palace_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Magazine_Palace_Pro_Switch_Control( $wp_customize, 'magazine_palace_pro_theme_options[featured_post_section_enable]', array(
	'label'             => esc_html__( 'Featred Post Section Enable', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_featured_post_section',
	'on_off_label' 		=> magazine_palace_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'magazine_palace_pro_theme_options[featured_post_section_enable]',
        array(
            'selector'            => '#magazine_palace_pro_featured_post_section .tooltiptext',
            'settings'            => 'magazine_palace_pro_theme_options[featured_post_section_enable]',
        )
    );
}

$wp_customize->add_setting( 
    'magazine_palace_pro_theme_options_featured_post_setting_style',
    array(
        'sanitize_callback' => 'sanitize_text_field',
    )
);

$wp_customize->add_control( 
    new Magazine_Palace_Pro_Customize_Control_Section_Style( 
    $wp_customize,
    'magazine_palace_pro_theme_options_featured_post_setting_style',
        array(
            'section'       => 'magazine_palace_pro_featured_post_section',
            'active_callback' 	=> 'magazine_palace_pro_is_featured_post_section_enable',
            'choices'  => array(

                'setting'    => array(
                    'name' => esc_html__( 'Setting', 'magazine-palace-pro' ),
                    'section_id' => 'magazine_palace_pro_featured_post_section',
                ),
                
                'style'    => array(
                    'name' => esc_html__( 'Style', 'magazine-palace-pro' ),
                    'section_id' => 'magazine_palace_pro_featured_post_section_style',
                ),
            ),
        )
    )
);


// featured_post title setting and control
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[featured_post_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_post_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'magazine_palace_pro_theme_options[featured_post_title]', array(
	'label'           	=> esc_html__( 'Title', 'magazine-palace-pro' ),
	'section'        	=> 'magazine_palace_pro_featured_post_section',
	'active_callback' 	=> 'magazine_palace_pro_is_featured_post_section_enable',
	'type'				=> 'text',
	) );

// Event social icons number control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[featured_post_count]', array(
	'default'          	=> $options['featured_post_count'],
	'sanitize_callback' => 'magazine_palace_pro_sanitize_number_range',
	) );

$wp_customize->add_control( 'magazine_palace_pro_theme_options[featured_post_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'magazine-palace-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_featured_post_section',
	'active_callback'   => 'magazine_palace_pro_is_featured_post_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
	) );


// Featred Post content type control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[featured_post_content_type]', array(
	'default'          	=> $options['featured_post_content_type'],
	'sanitize_callback' => 'magazine_palace_pro_sanitize_select',
	) );

$wp_customize->add_control( 'magazine_palace_pro_theme_options[featured_post_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_featured_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'magazine_palace_pro_is_featured_post_section_enable',
	'choices'			=> array( 
		'post' 		=> esc_html__( 'Post', 'magazine-palace-pro' ),
		'category' 	=> esc_html__( 'Category', 'magazine-palace-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['featured_post_count']; $i++ ) :


// featured_post posts drop down chooser control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[featured_post_content_post_' . $i . ']', array(
	'sanitize_callback' => 'magazine_palace_pro_sanitize_page',
	) );

$wp_customize->add_control( new Magazine_Palace_Pro_Dropdown_Chooser( $wp_customize, 'magazine_palace_pro_theme_options[featured_post_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'magazine-palace-pro' ), $i ),
	'section'           => 'magazine_palace_pro_featured_post_section',
	'choices'			=> magazine_palace_pro_post_choices(),
	'active_callback'	=> 'magazine_palace_pro_is_featured_post_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'magazine_palace_pro_theme_options[featured_post_content_category]', array(
	'sanitize_callback' => 'magazine_palace_pro_sanitize_category_list',
	) ) ;

$wp_customize->add_control( new Magazine_Palace_Pro_Dropdown_Category_Control( $wp_customize,'magazine_palace_pro_theme_options[featured_post_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'magazine-palace-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_featured_post_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'magazine_palace_pro_is_featured_post_section_content_category_enable'
	) ) );
