<?php
/**
* Three Col Slider Section options
*
* @package Theme Palace
* @subpackage Magazine Palace Pro
* @since Magazine Palace Pro 1.0.0
*/

// Add Three Col Slider section
$wp_customize->add_section( 'magazine_palace_pro_three_col_slider_section', array(
	'title'             => esc_html__( 'Three Col Slider','magazine-palace-pro' ),
	'description'       => esc_html__( 'Three Col Slider Section options.', 'magazine-palace-pro' ),
	'panel'             => 'magazine_palace_pro_front_page_panel',
	) );

// Three Col Slider content enable control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[three_col_slider_section_enable]', array(
	'default'			=> 	$options['three_col_slider_section_enable'],
	'sanitize_callback' => 'magazine_palace_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Magazine_Palace_Pro_Switch_Control( $wp_customize, 'magazine_palace_pro_theme_options[three_col_slider_section_enable]', array(
	'label'             => esc_html__( 'Three Col Slider Section Enable', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_three_col_slider_section',
	'on_off_label' 		=> magazine_palace_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'magazine_palace_pro_theme_options[three_col_slider_section_enable]',
        array(
            'selector'            => '#magazine_palace_pro_three_col_slider_section .tooltiptext',
            'settings'            => 'magazine_palace_pro_theme_options[three_col_slider_section_enable]',
        )
    );
}

$wp_customize->add_setting( 
    'magazine_palace_pro_theme_options_three_col_slider_setting_style',
    array(
        'sanitize_callback' => 'sanitize_text_field',
    )
);

$wp_customize->add_control( 
    new Magazine_Palace_Pro_Customize_Control_Section_Style( 
    $wp_customize,
    'magazine_palace_pro_theme_options_three_col_slider_setting_style',
        array(
            'section'       => 'magazine_palace_pro_three_col_slider_section',
            'active_callback' 	=> 'magazine_palace_pro_is_three_col_slider_section_enable',
            'choices'  => array(

                'setting'    => array(
                    'name' => esc_html__( 'Setting', 'magazine-palace-pro' ),
                    'section_id' => 'magazine_palace_pro_three_col_slider_section',
                ),
                
                'style'    => array(
                    'name' => esc_html__( 'Style', 'magazine-palace-pro' ),
                    'section_id' => 'magazine_palace_pro_three_col_slider_section_style',
                ),
            ),
        )
    )
);

$wp_customize->add_setting( 'magazine_palace_pro_theme_options[three_col_slider_autoplay_enable]', array(
	'default'			=> 	$options['three_col_slider_autoplay_enable'],
	'sanitize_callback' => 'magazine_palace_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Magazine_Palace_Pro_Switch_Control( $wp_customize, 'magazine_palace_pro_theme_options[three_col_slider_autoplay_enable]', array(
	'label'             => esc_html__( 'Slider Autoplay Enable', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_three_col_slider_section',
	'active_callback' 	=> 'magazine_palace_pro_is_three_col_slider_section_enable',
	'on_off_label' 		=> magazine_palace_pro_switch_options(),
) ) );


// three_col_slider title setting and control
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[three_col_slider_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['three_col_slider_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'magazine_palace_pro_theme_options[three_col_slider_title]', array(
	'label'           	=> esc_html__( 'Title', 'magazine-palace-pro' ),
	'section'        	=> 'magazine_palace_pro_three_col_slider_section',
	'active_callback' 	=> 'magazine_palace_pro_is_three_col_slider_section_enable',
	'type'				=> 'text',
	) );

// Event social icons number control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[three_col_slider_count]', array(
	'default'          	=> $options['three_col_slider_count'],
	'sanitize_callback' => 'magazine_palace_pro_sanitize_number_range',
	) );

$wp_customize->add_control( 'magazine_palace_pro_theme_options[three_col_slider_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'magazine-palace-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_three_col_slider_section',
	'active_callback'   => 'magazine_palace_pro_is_three_col_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );


// Three Col Slider content type control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[three_col_slider_content_type]', array(
	'default'          	=> $options['three_col_slider_content_type'],
	'sanitize_callback' => 'magazine_palace_pro_sanitize_select',
) );

$wp_customize->add_control( 'magazine_palace_pro_theme_options[three_col_slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_three_col_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'magazine_palace_pro_is_three_col_slider_section_enable',
	'choices'			=> array( 
		'post' 		=> esc_html__( 'Post', 'magazine-palace-pro' ),
		'category' 	=> esc_html__( 'Category', 'magazine-palace-pro' ),
		),
) );

for ( $i = 1; $i <= $options['three_col_slider_count']; $i++ ) :


// three_col_slider posts drop down chooser control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[three_col_slider_content_post_' . $i . ']', array(
	'sanitize_callback' => 'magazine_palace_pro_sanitize_page',
) );

$wp_customize->add_control( new Magazine_Palace_Pro_Dropdown_Chooser( $wp_customize, 'magazine_palace_pro_theme_options[three_col_slider_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'magazine-palace-pro' ), $i ),
	'section'           => 'magazine_palace_pro_three_col_slider_section',
	'choices'			=> magazine_palace_pro_post_choices(),
	'active_callback'	=> 'magazine_palace_pro_is_three_col_slider_section_content_post_enable',
) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'magazine_palace_pro_theme_options[three_col_slider_content_category]', array(
	'sanitize_callback' => 'magazine_palace_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Magazine_Palace_Pro_Dropdown_Category_Control( $wp_customize,'magazine_palace_pro_theme_options[three_col_slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'magazine-palace-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_three_col_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'magazine_palace_pro_is_three_col_slider_section_content_category_enable'
) ) );
