<?php
/**
* two_section Section options
*
* @package Theme Palace
* @subpackage Magazine Palace Pro
* @since Magazine Palace Pro 1.0.0
*/

// Add two_section section
$wp_customize->add_section( 'magazine_palace_pro_two_section_section', array(
	'title'             => esc_html__( 'Two Section','magazine-palace-pro' ),
	'description'       => esc_html__( 'Two Section options.', 'magazine-palace-pro' ),
	'panel'             => 'magazine_palace_pro_front_page_panel',
	) );

// two_section content enable control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[two_section_section_enable]', array(
	'default'			=> 	$options['two_section_section_enable'],
	'sanitize_callback' => 'magazine_palace_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Magazine_Palace_Pro_Switch_Control( $wp_customize, 'magazine_palace_pro_theme_options[two_section_section_enable]', array(
	'label'             => esc_html__( 'Two Section Enable', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_two_section_section',
	'on_off_label' 		=> magazine_palace_pro_switch_options(),
	) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'magazine_palace_pro_theme_options[two_section_section_enable]',
        array(
            'selector'            => '#magazine_palace_pro_two_section_section .tooltiptext',
            'settings'            => 'magazine_palace_pro_theme_options[two_section_section_enable]',
        )
    );
}

$wp_customize->add_setting( 
    'magazine_palace_pro_theme_options_two_section_setting_style',
    array(
        'sanitize_callback' => 'sanitize_text_field',
    )
);

$wp_customize->add_control( 
    new Magazine_Palace_Pro_Customize_Control_Section_Style( 
    $wp_customize,
    'magazine_palace_pro_theme_options_two_section_setting_style',
        array(
            'section'       => 'magazine_palace_pro_two_section_section',
            'active_callback' 	=> 'magazine_palace_pro_is_two_section_section_enable',
            'choices'  => array(

                'setting'    => array(
                    'name' => esc_html__( 'Setting', 'magazine-palace-pro' ),
                    'section_id' => 'magazine_palace_pro_two_section_section',
                ),
                
                'style'    => array(
                    'name' => esc_html__( 'Style', 'magazine-palace-pro' ),
                    'section_id' => 'magazine_palace_pro_two_section_section_style',
                ),
            ),
        )
    )
);

// two_section btn title setting and control
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[two_section_title_one]', array(
	'default'			=> 	$options['two_section_title_one'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'magazine_palace_pro_theme_options[two_section_title_one]', array(
	'label'           	=>  esc_html__( 'Slider Post Title', 'magazine-palace-pro' ),
	'section'        	=> 'magazine_palace_pro_two_section_section',
	'active_callback' 	=> 'magazine_palace_pro_is_two_section_section_enable',
	'type'				=> 'text',
	) );

$wp_customize->add_setting( 'magazine_palace_pro_theme_options[two_section_title_two]', array(
	'default'			=> 	$options['two_section_title_two'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'magazine_palace_pro_theme_options[two_section_title_two]', array(
	'label'           	=>  esc_html__( 'Grid Post Title', 'magazine-palace-pro' ),
	'section'        	=> 'magazine_palace_pro_two_section_section',
	'active_callback' 	=> 'magazine_palace_pro_is_two_section_section_enable',
	'type'				=> 'text',
	) );


// two_section auto play enable control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[two_section_auto_play]', array(
	'default'			=> 	$options['two_section_auto_play'],
	'sanitize_callback' => 'magazine_palace_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Magazine_Palace_Pro_Switch_Control( $wp_customize, 'magazine_palace_pro_theme_options[two_section_auto_play]', array(
	'label'             => esc_html__( 'Slider Auto Play Enable', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_two_section_section',
	'on_off_label' 		=> magazine_palace_pro_switch_options(),
	'active_callback'   => 'magazine_palace_pro_is_two_section_section_enable',
) ) );

$wp_customize->add_setting(  'magazine_palace_pro_theme_options[two_section_slider_category]', array(
	'sanitize_callback' => 'magazine_palace_pro_sanitize_category_list',
	) ) ;

$wp_customize->add_control( new Magazine_Palace_Pro_Dropdown_Category_Control( $wp_customize,'magazine_palace_pro_theme_options[two_section_slider_category]', array(
	'label'             => esc_html__( 'Select Category For Slider', 'magazine-palace-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_two_section_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'magazine_palace_pro_is_two_section_section_enable'
	) ) );


$wp_customize->add_setting( 'magazine_palace_pro_theme_options[two_section_grid_post_content_type]', array(
	'default'          	=> $options['two_section_grid_post_content_type'],
	'sanitize_callback' => 'magazine_palace_pro_sanitize_select',
	) );

$wp_customize->add_control( 'magazine_palace_pro_theme_options[two_section_grid_post_content_type]', array(
	'label'             => esc_html__( 'Grid Post Content Type', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_two_section_section',
	'type'				=> 'select',
	'active_callback' 	=> 'magazine_palace_pro_is_two_section_section_enable',
	'choices'			=> array( 
		'post' 		=> esc_html__( 'Post', 'magazine-palace-pro' ),
		'category' 	=> esc_html__( 'Category', 'magazine-palace-pro' ),
		),
	) );


// two_section pages drop down chooser control and setting
for ( $i = 1; $i <= 4; $i++ ) :

// two_section_logo posts drop down chooser control and setting
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[two_section_grid_post_content_post_' . $i . ']', array(
	'sanitize_callback' => 'magazine_palace_pro_sanitize_page',
	) );

$wp_customize->add_control( new Magazine_Palace_Pro_Dropdown_Chooser( $wp_customize, 'magazine_palace_pro_theme_options[two_section_grid_post_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'magazine-palace-pro' ), $i ),
	'section'           => 'magazine_palace_pro_two_section_section',
	'choices'			=> magazine_palace_pro_post_choices(),
	'active_callback'	=> 'magazine_palace_pro_is_two_section_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'magazine_palace_pro_theme_options[two_section_grid_post_content_category]', array(
	'sanitize_callback' => 'magazine_palace_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Magazine_Palace_Pro_Dropdown_Category_Control( $wp_customize,'magazine_palace_pro_theme_options[two_section_grid_post_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'magazine-palace-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press CTRL key select multilple categories.', 'magazine-palace-pro' ),
	'section'           => 'magazine_palace_pro_two_section_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'magazine_palace_pro_is_two_section_section_content_category_enable'
	) ) );

