<?php
/**
 * Layout options
 *
 * @package Theme Palace
 * @subpackage Magazine Palace Pro
 * @since Magazine Palace Pro 1.0.0
 */

// Add sidebar section
$wp_customize->add_section( 'magazine_palace_pro_layout', array(
	'title'               => esc_html__('Layout','magazine-palace-pro'),
	'description'         => esc_html__( 'Layout section options.', 'magazine-palace-pro' ),
	'panel'               => 'magazine_palace_pro_theme_options_panel',
) );

// Site layout setting and control.
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[site_layout]', array(
	'sanitize_callback'   => 'magazine_palace_pro_sanitize_select',
	'default'             => $options['site_layout'],
) );

$wp_customize->add_control(  new Magazine_Palace_Pro_Custom_Radio_Image_Control ( $wp_customize, 'magazine_palace_pro_theme_options[site_layout]', array(
	'label'               => esc_html__( 'Site Layout', 'magazine-palace-pro' ),
	'section'             => 'magazine_palace_pro_layout',
	'choices'			  => magazine_palace_pro_site_layout(),
) ) );

// Sidebar position setting and control.
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[sidebar_position]', array(
	'sanitize_callback'   => 'magazine_palace_pro_sanitize_select',
	'default'             => $options['sidebar_position'],
) );

$wp_customize->add_control(  new Magazine_Palace_Pro_Custom_Radio_Image_Control ( $wp_customize, 'magazine_palace_pro_theme_options[sidebar_position]', array(
	'label'               => esc_html__( 'Global Sidebar Position', 'magazine-palace-pro' ),
	'section'             => 'magazine_palace_pro_layout',
	'choices'			  => magazine_palace_pro_global_sidebar_position(),
) ) );

// Post sidebar position setting and control.
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[post_sidebar_position]', array(
	'sanitize_callback'   => 'magazine_palace_pro_sanitize_select',
	'default'             => $options['post_sidebar_position'],
) );

$wp_customize->add_control(  new Magazine_Palace_Pro_Custom_Radio_Image_Control ( $wp_customize, 'magazine_palace_pro_theme_options[post_sidebar_position]', array(
	'label'               => esc_html__( 'Posts Sidebar Position', 'magazine-palace-pro' ),
	'section'             => 'magazine_palace_pro_layout',
	'choices'			  => magazine_palace_pro_sidebar_position(),
) ) );

// Post sidebar position setting and control.
$wp_customize->add_setting( 'magazine_palace_pro_theme_options[page_sidebar_position]', array(
	'sanitize_callback'   => 'magazine_palace_pro_sanitize_select',
	'default'             => $options['page_sidebar_position'],
) );

$wp_customize->add_control( new Magazine_Palace_Pro_Custom_Radio_Image_Control( $wp_customize, 'magazine_palace_pro_theme_options[page_sidebar_position]', array(
	'label'               => esc_html__( 'Pages Sidebar Position', 'magazine-palace-pro' ),
	'section'             => 'magazine_palace_pro_layout',
	'choices'			  => magazine_palace_pro_sidebar_position(),
) ) );


$wp_customize->add_setting( 'magazine_palace_pro_theme_options[wrapper_width]', array(
    'sanitize_callback' => 'magazine_palace_pro_sanitize_number_range',
    'transport'         => 'postMessage'
    ) );

$wp_customize->add_control( 'magazine_palace_pro_theme_options[wrapper_width]', array(
    'label'             => esc_html__( 'Wrapper Width', 'magazine-palace-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 100.', 'magazine-palace-pro' ),
    'section'           => 'magazine_palace_pro_layout',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 100,
        'style' => 'width: 100px;'
        ),
    ) );

$wp_customize->add_setting( 'magazine_palace_pro_theme_options[wrapper_max_width]', array(
    'sanitize_callback' => 'magazine_palace_pro_sanitize_number_range',
    'transport'         => 'postMessage'
    ) );

$wp_customize->add_control( 'magazine_palace_pro_theme_options[wrapper_max_width]', array(
    'label'             => esc_html__( 'Wrapper Max Width', 'magazine-palace-pro' ),
    'section'           => 'magazine_palace_pro_layout',
    'type'              => 'number',
    ) );