<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Magazine Palace Pro
 * @since Magazine Palace Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function magazine_palace_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'magazine-palace-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function magazine_palace_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'magazine-palace-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function magazine_palace_pro_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'magazine-palace-pro' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

if ( ! function_exists( 'magazine_palace_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function magazine_palace_pro_typography_options(){
        $font_family_arr = array();
        $font_family_arr[''] = esc_html__( '--Default--', 'magazine-palace-pro' );

        // Make the request
        $request = wp_remote_get( get_theme_file_uri( 'assets/webfonts.json' ) );

        if( is_wp_error( $request ) ) {
            return false; // Bail early
        }
         // Retrieve the data
        $body = wp_remote_retrieve_body( $request );
        $data = json_decode( $body );
        if ( ! empty( $data ) ) {
            foreach ( $data->items as $items => $fonts ) {
                $family_str_arr = explode( ' ', $fonts->family );
                $family_value = implode( '+', $family_str_arr );
                $font_family_arr[ $family_value ] = $fonts->family;
            }
        }

        return $font_family_arr;
    }
endif;


if ( ! function_exists( 'magazine_palace_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function magazine_palace_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'magazine-palace-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'magazine-palace-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'magazine-palace-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'magazine-palace-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'magazine-palace-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'magazine-palace-pro' ),
        );

        $output = apply_filters( 'magazine_palace_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'magazine_palace_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function magazine_palace_pro_site_layout() {
        $magazine_palace_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'magazine_palace_pro_site_layout', $magazine_palace_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'magazine_palace_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function magazine_palace_pro_selected_sidebar() {
        $magazine_palace_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'magazine-palace-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'magazine-palace-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'magazine-palace-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'magazine-palace-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'magazine-palace-pro' ),
        );

        $output = apply_filters( 'magazine_palace_pro_selected_sidebar', $magazine_palace_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'magazine_palace_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function magazine_palace_pro_global_sidebar_position() {
        $magazine_palace_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'magazine_palace_pro_global_sidebar_position', $magazine_palace_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'magazine_palace_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function magazine_palace_pro_sidebar_position() {
        $magazine_palace_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'magazine_palace_pro_sidebar_position', $magazine_palace_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'magazine_palace_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function magazine_palace_pro_pagination_options() {
        $magazine_palace_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'magazine-palace-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'magazine-palace-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'magazine-palace-pro' ),
        );

        $output = apply_filters( 'magazine_palace_pro_pagination_options', $magazine_palace_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'magazine_palace_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function magazine_palace_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'magazine-palace-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'magazine-palace-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'magazine-palace-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'magazine-palace-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'magazine-palace-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'magazine-palace-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'magazine-palace-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'magazine-palace-pro' ),
        );
        return apply_filters( 'magazine_palace_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'magazine_palace_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function magazine_palace_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'magazine-palace-pro' ),
            'off'       => esc_html__( 'Disable', 'magazine-palace-pro' )
        );
        return apply_filters( 'magazine_palace_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'magazine_palace_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function magazine_palace_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'magazine-palace-pro' ),
            'off'       => esc_html__( 'No', 'magazine-palace-pro' )
        );
        return apply_filters( 'magazine_palace_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'magazine_palace_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function magazine_palace_pro_sortable_sections() {
        $sections = array(
            'tag'  => esc_html__( 'Tag', 'magazine-palace-pro' ),
            'breakingnews'  => esc_html__( 'Breaking News', 'magazine-palace-pro' ),
            'slider_news'    => esc_html__( 'Slider News', 'magazine-palace-pro' ),
            'two_section'    => esc_html__( 'Two Section', 'magazine-palace-pro' ),
            'multi_post'    => esc_html__( 'Multi Post', 'magazine-palace-pro' ),
            'post_carousel'    => esc_html__( 'Post Carousel', 'magazine-palace-pro' ),
            'have_missed'    => esc_html__( 'Have Missed', 'magazine-palace-pro' ),
            'featured_post'    => esc_html__( 'Featured Post', 'magazine-palace-pro' ),
            'main_slider'    => esc_html__( 'Main Slider', 'magazine-palace-pro' ),
            'featured_category'    => esc_html__( 'Featured Category', 'magazine-palace-pro' ),
            'blog_slider'    => esc_html__( 'Blog Slider', 'magazine-palace-pro' ),
            'main_content'    => esc_html__( 'Main Content', 'magazine-palace-pro' ),
            'instagram'    => esc_html__( 'Instagram', 'magazine-palace-pro' ),
          );
        return apply_filters( 'magazine_palace_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'magazine_palace_pro_inner_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function magazine_palace_pro_inner_sortable_sections() {
        $sections = array(
            'post_grid'  => esc_html__( 'Post Grid', 'magazine-palace-pro' ),
            'banner_post'  => esc_html__( 'Banner Post', 'magazine-palace-pro' ),
            'sport_post'    => esc_html__( 'Sport Post', 'magazine-palace-pro' ),
            'featured_slider'    => esc_html__( 'Featured Slider', 'magazine-palace-pro' ),
            'three_col_slider'    => esc_html__( 'Three Col Slider', 'magazine-palace-pro' ),
            'two_col'    => esc_html__( 'Two Col', 'magazine-palace-pro' ),
            'latest_post'    => esc_html__( 'Latest Post', 'magazine-palace-pro' ),
          );
        return apply_filters( 'magazine_palace_pro_inner_sortable_sections', $sections );
    }
endif;

function magazine_palace_pro_get_post_cat_choices() {
  $choices = array( '' => esc_html__( '--Select--', 'magazine-palace-pro' ) );
    $cats = get_categories();
    foreach ( $cats as $cat ) {
        $id = $cat->term_id;
        $title = $cat->name;
        $choices[ $id ] = $title;
    }
    return $choices;
}