<?php
/**
* Blog Slider section
*
* This is the template for the content of blog_slider section
*
* @package Theme Palace
* @subpackage Magazine Palace Pro
* @since Magazine Palace Pro 1.0.0
*/
if ( ! function_exists( 'magazine_palace_pro_add_blog_slider_section' ) ) :
/**
* Add blog_slider section
*
*@since Magazine Palace Pro 1.0.0
*/
function magazine_palace_pro_add_blog_slider_section() {
    $options = magazine_palace_pro_get_theme_options();
    // Check if blog_slider is enabled on frontpage
    $blog_slider_enable = apply_filters( 'magazine_palace_pro_section_status', true, 'blog_slider_section_enable' );

    if ( true !== $blog_slider_enable ) {
        return false;
    }
    // Get blog_slider section details
    $section_details = array();
    $section_details = apply_filters( 'magazine_palace_pro_filter_blog_slider_section_details', $section_details );

    if ( empty( $section_details ) ) {
        return;
    }

// Render blog_slider section now.
    magazine_palace_pro_render_blog_slider_section( $section_details );
}
endif;

if ( ! function_exists( 'magazine_palace_pro_get_blog_slider_section_details' ) ) :
/**
* blog_slider section details.
*
* @since Magazine Palace Pro 1.0.0
* @param array $input blog_slider section details.
*/
function magazine_palace_pro_get_blog_slider_section_details( $input ) {
    $options = magazine_palace_pro_get_theme_options();

// Content type.
    $blog_slider_content_type  = $options['blog_slider_content_type'];
    $blog_slider_count = ! empty( $options['blog_slider_count'] ) ? $options['blog_slider_count'] : 4;

    $content = array();
    switch ( $blog_slider_content_type ) {

        case 'post':
        $post_ids = array();

        for ( $i = 1; $i <= $blog_slider_count; $i++ ) {
            if ( ! empty( $options['blog_slider_content_post_' . $i] ) )
                $post_ids[] = $options['blog_slider_content_post_' . $i];
        }

        $args = array(
            'post_type'         => 'post',
            'post__in'          => ( array ) $post_ids,
            'posts_per_page'    => absint( $blog_slider_count ),
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
            );                    
        break;

        case 'category':
        $cat_id = ! empty( $options['blog_slider_content_category'] ) ? $options['blog_slider_content_category'] : '';
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => absint( $blog_slider_count ),
            'category__in'      => ( array ) $cat_id,
            'ignore_sticky_posts'   => true,
            );                    
        break;

        default:
        break;
    }


// Run The Loop.
    $query = new WP_Query( $args );
    if ( $query->have_posts() ) : 
        while ( $query->have_posts() ) : $query->the_post();
    $page_post['id']        = get_the_id();
    $page_post['title']     = get_the_title();
    $page_post['auth_id']   = get_the_author_meta('ID');
    $page_post['url']       = get_the_permalink();
    $page_post['excerpt']   = get_the_content();
    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

// Push to the main array.
    array_push( $content, $page_post );
    endwhile;
    endif;
    wp_reset_postdata();

    if ( ! empty( $content ) ) {
        $input = $content;
    }
    return $input;
}
endif;
// blog_slider section content details.
add_filter( 'magazine_palace_pro_filter_blog_slider_section_details', 'magazine_palace_pro_get_blog_slider_section_details' );


if ( ! function_exists( 'magazine_palace_pro_render_blog_slider_section' ) ) :
/**
* Start blog_slider section
*
* @return string blog_slider content
* @since Magazine Palace Pro 1.0.0
*
*/
function magazine_palace_pro_render_blog_slider_section( $content_details = array() ) {
    $options = magazine_palace_pro_get_theme_options();
  ?>
<div id="magazine_palace_pro_blog_slider_section" class="relative home-section blog-slide">
    <div class="wrapper">
        <?php if ( is_customize_preview()):
            magazine_palace_pro_section_tooltip( 'blog-slide-class' );
        endif; ?>
        <div class="blog-slider" data-slick='{"slidesToShow": 4, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": <?php echo esc_attr( $options['blog_slider_autoplay_enable'] ) ?>, "draggable": true, "fade": false }'>
            <?php foreach ( $content_details as $content ) : ?>
                <article>
                    <div class="blog-slider-wrapper">
                        <div class="featured-image">
                            <img src="<?php echo esc_url( $content['image'] ); ?>">
                        </div>
                       <?php if ( !empty( get_post_meta( $content['id'], '_magazine_palace_pro_youtube_video_code' )[0] ) ): ?>
                            <div class="video-button">
                                <a href="https://www.youtube.com/watch?v=<?php echo get_post_meta( $content['id'], '_magazine_palace_pro_youtube_video_code' )[0] ?>" class="popup-video" tabindex="-1"><i class="fa fa-play"></i></a>
                            </div>
                        <?php endif ?>
                        <div class="entry-container">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>
                        </div>
                    </div>
                </article>
            <?php endforeach; ?>            
        </div>
        
    </div>
</div>

<?php }
    endif;