<?php
/**
 * Featured Posts section
 *
 * This is the template for the content of featured_category section
 *
 * @package Theme Palace
 * @subpackage magazine_palace Pro
 * @since magazine_palace Pro 1.0.0
 */
if ( ! function_exists( 'magazine_palace_pro_add_featured_category_section' ) ) :
    /**
    * Add featured_category section
    *
    *@since magazine_palace Pro 1.0.0
    */
    function magazine_palace_pro_add_featured_category_section() {
        $options = magazine_palace_pro_get_theme_options();
        // Check if featured_category is enabled on frontpage
        $featured_category_enable = apply_filters( 'magazine_palace_pro_section_status', true, 'featured_category_section_enable' );

        if ( ( true !== $featured_category_enable) ) {
            return false;
        }

        // Render featured_category section now.
        magazine_palace_pro_render_featured_category_section();
    }
endif;

if ( ! function_exists( 'magazine_palace_pro_render_featured_category_section' ) ) :
  /**
   * Start featured_category section
   *
   * @return string featured_category content
   * @since magazine_palace Pro 1.0.0
   *
   */
   function magazine_palace_pro_render_featured_category_section() {
        $options = magazine_palace_pro_get_theme_options();

    ?>

    <div id="magazine_palace_pro_featured_category_section" class="relative home-section featured-category">
        <div class="wrapper">
            <?php if ( is_customize_preview()):
                magazine_palace_pro_section_tooltip( 'featured-category-class' );
            endif; ?>
            <div class="section-contnet col-3 clear">
            <?php for ( $i=1; $i <= $options['featured_category_count']; $i++ ) {               
                $featured_category_category_image = !empty( $options['featured_category_category_image_' . $i] ) ? $options['featured_category_category_image_' . $i] : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                if ( empty($options['featured_category_content_featured_category_category_'.$i]) ) {
                    continue;
                }

                $thumbnail_id = get_term_meta( $options['featured_category_content_featured_category_category_'.$i], 'thumbnail_id', true );

                $cat_name = get_term_by( 'id', $options['featured_category_content_featured_category_category_'.$i], 'category' )->name;

                $cat_link = get_category_link( $options['featured_category_content_featured_category_category_'.$i] );

                ?>
                    <article>
                        <div class="recent-post-item">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $featured_category_category_image ); ?>');">
                                <a href="<?php echo esc_url( $cat_link ); ?>" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $cat_link ); ?>"><?php echo esc_html($cat_name);?></a></h2>
                            </header>
                        </div><!-- .recent-post-item -->
                    </article>
                <?php } ?>
            </div><!-- .col-3 -->
        </div><!-- .wrapper -->
    </div><!-- #magazine_palace_pro_featured_category_section -->
    <?php }
endif;

