<?php
/**
* Main Slider section
*
* This is the template for the content of main_slider section
*
* @package Theme Palace
* @subpackage Magazine Palace Pro
* @since Magazine Palace Pro 1.0.0
*/
if ( ! function_exists( 'magazine_palace_pro_add_main_slider_section' ) ) :
/**
* Add main_slider section
*
*@since Magazine Palace Pro 1.0.0
*/
function magazine_palace_pro_add_main_slider_section() {
    $options = magazine_palace_pro_get_theme_options();
    // Check if main_slider is enabled on frontpage
    $main_slider_enable = apply_filters( 'magazine_palace_pro_section_status', true, 'main_slider_section_enable' );

    if ( true !== $main_slider_enable ) {
        return false;
    }
    // Get main_slider section details
    $section_details = array();
    $section_details = apply_filters( 'magazine_palace_pro_filter_main_slider_section_details', $section_details );

    if ( empty( $section_details ) ) {
        return;
    }

// Render main_slider section now.
    magazine_palace_pro_render_main_slider_section( $section_details );
}
endif;

if ( ! function_exists( 'magazine_palace_pro_get_main_slider_section_details' ) ) :
/**
* main_slider section details.
*
* @since Magazine Palace Pro 1.0.0
* @param array $input main_slider section details.
*/
function magazine_palace_pro_get_main_slider_section_details( $input ) {
    $options = magazine_palace_pro_get_theme_options();

    $main_slider_content_type  = $options['main_slider_content_type'];
    $main_slider_count = ! empty( $options['main_slider_count'] ) ? $options['main_slider_count'] : 3;

    $content_details = array();
    switch ( $main_slider_content_type ) {

        case 'page':
        $page_ids = array();

        for ( $i = 1; $i <= $main_slider_count; $i++ ) {
            if ( ! empty( $options['main_slider_content_page_' . $i] ) )
                $page_ids[] = $options['main_slider_content_page_' . $i];
        }

        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => absint( $main_slider_count ),
            'orderby'           => 'post__in',
            );                    
        break;

        case 'post':
        $post_ids = array();

        for ( $i = 1; $i <= $main_slider_count; $i++ ) {
            if ( ! empty( $options['main_slider_content_post_' . $i] ) )
                $post_ids[] = $options['main_slider_content_post_' . $i];
        }

        $args = array(
            'post_type'         => 'post',
            'post__in'          => ( array ) $post_ids,
            'posts_per_page'    => absint( $main_slider_count ),
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
            );                    
        break;

        case 'category':
        $cats_id = ! empty( $options['main_slider_content_category'] ) ? $options['main_slider_content_category'] : '';
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => absint( $main_slider_count ),
            'cat'               => absint( $cats_id ),
            'ignore_sticky_posts'   => true,
            );                    
        break;

        default:
        break;
    }

    // Run The Loop.
    $query = new WP_Query( $args );
    if ( $query->have_posts() ) : 
        while ( $query->have_posts() ) : $query->the_post();
        $page_post['id']        = get_the_id();
        $page_post['title']     = get_the_title();
        $page_post['excerpt']   = magazine_palace_pro_trim_content( 25 );
        $page_post['auth_id']   = get_the_author_meta('ID');
        $page_post['url']       = get_the_permalink();
        $page_post['image'] = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

    // Push to the main array.
    array_push( $content_details, $page_post );
    endwhile;
    endif;
    wp_reset_postdata();

    if ( ! empty( $content_details ) ) {
        $input = $content_details;
    }
    return $input;
}
endif;
// main_slider section content details.
add_filter( 'magazine_palace_pro_filter_main_slider_section_details', 'magazine_palace_pro_get_main_slider_section_details' );


if ( ! function_exists( 'magazine_palace_pro_render_main_slider_section' ) ) :
/**
* Start main_slider section
*
* @return string main_slider content
* @since Magazine Palace Pro 1.0.0
*
*/
function magazine_palace_pro_render_main_slider_section( $content_details = array() ) {
    $options = magazine_palace_pro_get_theme_options();
  ?>
<div id="magazine_palace_pro_main_slider_section" class="relative home-section main-slider">
    <?php if ( is_customize_preview()):
        magazine_palace_pro_section_tooltip( 'main-slider-class' );
    endif; ?>
    <div class="full-width-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 500, "dots": false, "arrows": true, "autoplay": false, "draggable": true, "fade": true, "adaptiveHeight": true }'>
        <?php foreach ( $content_details as $content ) : ?>
            <article style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                    <div class="featured-content-wrapper">
                        <div class="entry-container">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->

                            <div class="read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn">Get Started Now</a>
                            </div><!-- .read-more -->
                        </div><!-- .entry-container -->
                    </div><!-- .featured-content-wrapper -->
                </div><!-- .wrapper -->
            </article>
        <?php endforeach; ?> 
        
    </div><!-- .full-width-slider -->
</div><!-- #magazine_palace_pro_main_slider_section -->
<?php }
    endif;

