<?php
/**
* Related post section
*
* This is the template for the content of multi_post section
*
* @package Theme Palace
* @subpackage Magazine Palace Pro
* @since Magazine Palace Pro 1.0.0
*/
if ( ! function_exists( 'magazine_palace_pro_add_multi_post_section' ) ) :
/**
* Add multi_post section
*
*@since Magazine Palace Pro 1.0.0
*/
function magazine_palace_pro_add_multi_post_section() {
    $options = magazine_palace_pro_get_theme_options();
    // Check if multi_post is enabled on frontpage
    $multi_post_enable = apply_filters( 'magazine_palace_pro_section_status', true, 'multi_post_section_enable' );

    if ( true !== $multi_post_enable ) {
        return false;
    }
    // Get multi_post section details
    $section_details = array();
    $section_details = apply_filters( 'magazine_palace_pro_filter_multi_post_section_details', $section_details );

    if ( empty( $section_details ) ) {
        return;
    }

// Render multi_post section now.
    magazine_palace_pro_render_multi_post_section( $section_details );
}
endif;

if ( ! function_exists( 'magazine_palace_pro_get_multi_post_section_details' ) ) :
/**
* multi_post section details.
*
* @since Magazine Palace Pro 1.0.0
* @param array $input multi_post section details.
*/
function magazine_palace_pro_get_multi_post_section_details( $input ) {
    $options = magazine_palace_pro_get_theme_options();

   // Content type.
    $multi_post_col1_content_type  = $options['multi_post_col1_content_type'];
    $multi_post_col1_count = ! empty( $options['multi_post_col1_count'] ) ? $options['multi_post_col1_count'] : 6;

    $content_details = array();
    switch ( $multi_post_col1_content_type ) {
 
        case 'post':

            $post_ids = array();
            for ( $i = 1; $i <= $multi_post_col1_count; $i++ ) {
                if ( ! empty( $options['multi_post_col1_content_post_' . $i] ) )
                    $post_ids[] = $options['multi_post_col1_content_post_' . $i];
            }
            $col1_args = array(
                'post_type'         => 'post',
                'post__in'          => ( array ) $post_ids,
                'posts_per_page'    => absint( $multi_post_col1_count ),
                'orderby'           => 'post__in',
                'ignore_sticky_posts'   => true,
                );
            break;

        case 'category':
            $cat_ids = ! empty( $options['multi_post_col1_content_category'] ) ? $options['multi_post_col1_content_category'] : '';
            $col1_args = array(
                'post_type'         => 'post',
                'posts_per_page'    => absint( $multi_post_col1_count ),
                'cat'               => absint( $cat_ids ),
                'ignore_sticky_posts'   => true,
                );
            break;
        default:
        break;
    }

    // Run The Loop.
    $query = new WP_Query( $col1_args );
    if ( $query->have_posts() ) :
        $content_details['col1']  = array();
        while ( $query->have_posts() ) : $query->the_post();
            $page_post['id']        = get_the_id();
            $page_post['auth_id']   = get_the_author_meta('ID');
            $page_post['title']     = get_the_title();
            $page_post['excerpt']   = get_the_content();
            $page_post['url']       = get_the_permalink();
            $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

            // Push to the main array.
            array_push( $content_details['col1'], $page_post );
        endwhile;
    endif;
    wp_reset_postdata();

    // Content type.
    $multi_post_col2_content_type  = $options['multi_post_col2_content_type'];
    $multi_post_col2_count = ! empty( $options['multi_post_col2_count'] ) ? $options['multi_post_col2_count'] : 6;
    switch ( $multi_post_col2_content_type ) {
        case 'post':

            $post_ids = array();
            for ( $i = 1; $i <= $multi_post_col2_count; $i++ ) {
                if ( ! empty( $options['multi_post_col2_content_post_' . $i] ) )
                    $post_ids[] = $options['multi_post_col2_content_post_' . $i];
            }

            $col2_args = array(
                'post_type'         => 'post',
                'post__in'          => (empty($post_ids)) ? array(0) : ( array ) $post_ids,
                'posts_per_page'    => absint( $multi_post_col2_count ),
                'orderby'           => 'post__in',
                'ignore_sticky_posts'   => true,
                );
            break;

        case 'category':
            $cat_ids = ! empty( $options['multi_post_col2_content_category'] ) ? $options['multi_post_col2_content_category'] : '';
            $col2_args = array(
                'post_type'         => 'post',
                'posts_per_page'    => absint( $multi_post_col2_count ),
                'cat'               =>  $cat_ids,
                'ignore_sticky_posts'   => true,
                );
            break;
        default:
        break;
    }
    // Run The Loop.
    $query = new WP_Query( $col2_args );
    if ( $query->have_posts() ) :
        $content_details['col2'] = array();
        while ( $query->have_posts() ) : $query->the_post();
            $page_post['id']        = get_the_id();
            $page_post['auth_id']   = get_the_author_meta('ID');
            $page_post['title']     = get_the_title();
            $page_post['excerpt']   = get_the_content();
            $page_post['url']       = get_the_permalink();
            $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

            // Push to the main array.
            array_push( $content_details['col2'], $page_post );
        endwhile;
    endif;
    wp_reset_postdata();

    // Content type.
    $multi_post_col3_content_type  = $options['multi_post_col3_content_type'];
    $multi_post_col3_count = ! empty( $options['multi_post_col3_count'] ) ? $options['multi_post_col3_count'] : 6;
    switch ( $multi_post_col3_content_type ) {

        case 'post':

            $post_ids = array();
            for ( $i = 1; $i <= $multi_post_col3_count; $i++ ) {
                if ( ! empty( $options['multi_post_col3_content_post_' . $i] ) )
                    $post_ids[] = $options['multi_post_col3_content_post_' . $i];
            }

            $col3_args = array(
                'post_type'         => 'post',
                'post__in'          => (empty($post_ids)) ? array(0) : ( array ) $post_ids,
                'posts_per_page'    => absint( $multi_post_col3_count ),
                'orderby'           => 'post__in',
                'ignore_sticky_posts'   => true,
                );
            break;

        case 'category':
            $cat_ids = ! empty( $options['multi_post_col3_content_category'] ) ? $options['multi_post_col3_content_category'] : '';
            $col3_args = array(
                'post_type'         => 'post',
                'posts_per_page'    => absint( $multi_post_col3_count ),
                'cat'               =>  $cat_ids,
                'ignore_sticky_posts'   => true,
                );
            break;
        default:
        break;
    }
    // Run The Loop.
    $query = new WP_Query( $col3_args );
    if ( $query->have_posts() ) :
        $content_details['col3'] = array();
        while ( $query->have_posts() ) : $query->the_post();
            $page_post['id']        = get_the_id();
            $page_post['auth_id']   = get_the_author_meta('ID');
            $page_post['title']     = get_the_title();
            $page_post['excerpt']   = get_the_content();
            $page_post['url']       = get_the_permalink();
            $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

            // Push to the main array.
            array_push( $content_details['col3'], $page_post );
        endwhile;
    endif;
    wp_reset_postdata();

    if ( ! empty( $content_details ) ) {
        $input = $content_details;
    }
    return $input;
}
endif;
// multi_post section content details.
add_filter( 'magazine_palace_pro_filter_multi_post_section_details', 'magazine_palace_pro_get_multi_post_section_details' );


if ( ! function_exists( 'magazine_palace_pro_render_multi_post_section' ) ) :
/**
* Start multi_post section
*
* @return string multi_post content
* @since Magazine Palace Pro 1.0.0
*
*/
function magazine_palace_pro_render_multi_post_section( $content_details = array() ) {
    $options = magazine_palace_pro_get_theme_options();

    if ( empty( $content_details ) ) {
        return;
    } ?>

    <div id="magazine_palace_pro_multi_post_section" class="relative home-section multi-post">
        <div class="wrapper">
            <?php if ( is_customize_preview()):
                magazine_palace_pro_section_tooltip( 'multi-post-class' );
            endif; ?>
            <div class="section-content col-3">
                <article class="first-col">
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html($options['multi_post_col1_title']); ?></h2>
                    </div><!-- .section-header -->
                    <ul>
                        <?php if ( !empty( $content_details['col1'] ) ): ?>
                            
                        <?php endif ?>
                        <?php foreach( $content_details['col1'] as $key => $content ) : ?>
                           
                            <li>
                                <div class="magazine_palace_pro_two_col_section-wrapper">
                                    <div class="featured-image">
                                        <img src="<?php echo esc_url($content['image']); ?>">
                                    </div>
                                    <?php if ( !empty( get_post_meta( $content['id'], '_magazine_palace_pro_youtube_video_code' )[0] ) ): ?>
                                        <div class="video-button">
                                            <a href="https://www.youtube.com/watch?v=<?php echo get_post_meta( $content['id'], '_magazine_palace_pro_youtube_video_code' )[0] ?>" class="popup-video" tabindex="-1"><i class="fa fa-play"></i></a>
                                        </div>
                                    <?php endif ?>
                                    
                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>
                                        <div class="entry-meta">
                                            <?php magazine_palace_pro_posted_on( $content['id'] ); ?>
                                            <span class="min-read"><?php echo magazine_palace_pro_time_interval($content['excerpt']); echo esc_html__(' min to read', 'magazine-palace-pro'); ?></span>
                                        </div>
                                    </div><!-- .entry-container -->
                                </div>
                            </li>
                        <?php endforeach; ?>
                    </ul>
                </article>
                <article class="second-col">
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html($options['multi_post_col2_title']); ?></h2>
                    </div><!-- .section-header -->
                    <ul>
                        <?php if ( !empty( $content_details['col2'] ) ): ?>
                             <?php foreach( $content_details['col2'] as $key => $content ) : ?>
                                <li>
                                    <div class="magazine_palace_pro_two_col_section-wrapper">
                                        <div class="featured-image">
                                            <img src="<?php echo esc_url($content['image']); ?>">
                                        </div>
                                       <?php if ( !empty( get_post_meta( $content['id'], '_magazine_palace_pro_youtube_video_code' )[0] ) ): ?>
                                            <div class="video-button">
                                                <a href="https://www.youtube.com/watch?v=<?php echo get_post_meta( $content['id'], '_magazine_palace_pro_youtube_video_code' )[0] ?>" class="popup-video" tabindex="-1"><i class="fa fa-play"></i></a>
                                            </div>
                                        <?php endif ?>
                                        <div class="entry-container">
                                            <header class="entry-header">
                                                <h2 class="entry-title"><a href="<?php echo esc_url($content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                            </header>
                                            <div class="entry-meta">
                                                <?php magazine_palace_pro_posted_on( $content['id'] ); ?>
                                                <span class="min-read"><?php echo magazine_palace_pro_time_interval($content['excerpt']); echo esc_html__(' min to read', 'magazine-palace-pro'); ?></span>
                                            </div>
                                        </div><!-- .entry-container -->
                                    </div>
                                </li>
                            <?php endforeach; ?>
                        <?php endif ?>                       
                    </ul>
                </article>
                <article class="third-col">
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html($options['multi_post_col3_title']); ?></h2>
                    </div><!-- .section-header -->
                    <ul>
                        <?php if ( !empty( $content_details['col3'] ) ): ?>
                            <?php foreach( $content_details['col3'] as $key => $content ) : ?>

                                <li>
                                    <div class="magazine_palace_pro_two_col_section-wrapper">
                                        <div class="featured-image">
                                            <img src="<?php echo esc_url($content['image']); ?>">
                                        </div>
                                        <?php if ( !empty( get_post_meta( $content['id'], '_magazine_palace_pro_youtube_video_code' )[0] ) ): ?>
                                            <div class="video-button">
                                                <a href="https://www.youtube.com/watch?v=<?php echo get_post_meta( $content['id'], '_magazine_palace_pro_youtube_video_code' )[0] ?>" class="popup-video" tabindex="-1"><i class="fa fa-play"></i></a>
                                            </div>
                                        <?php endif ?>
                                        <div class="entry-container">
                                            <header class="entry-header">
                                                <h2 class="entry-title"><a href="<?php echo esc_url($content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                            </header>
                                            <div class="entry-meta">
                                                <?php magazine_palace_pro_posted_on( $content['id'] ); ?>
                                                <span class="min-read"><?php echo magazine_palace_pro_time_interval($content['excerpt']); echo esc_html__(' min to read', 'magazine-palace-pro'); ?></span>
                                            </div>
                                        </div><!-- .entry-container -->
                                    </div>
                                </li>
                            <?php endforeach; ?>
                        <?php endif ?>                        
                    </ul>
                </article>
            </div>
        </div>
    </div><!-- #magazine_palace_pro_multi_post_section -->

<?php }
endif;

