<?php
/**
* Post Carousel section
*
* This is the template for the content of post_carousel section
*
* @package Theme Palace
* @subpackage Magazine Palace Pro
* @since Magazine Palace Pro 1.0.0
*/
if ( ! function_exists( 'magazine_palace_pro_add_post_carousel_section' ) ) :
/**
* Add post_carousel section
*
*@since Magazine Palace Pro 1.0.0
*/
function magazine_palace_pro_add_post_carousel_section() {
    $options = magazine_palace_pro_get_theme_options();
    // Check if post_carousel is enabled on frontpage
    $post_carousel_enable = apply_filters( 'magazine_palace_pro_section_status', true, 'post_carousel_section_enable' );

    if ( true !== $post_carousel_enable ) {
        return false;
    }
    // Get post_carousel section details
    $section_details = array();
    $section_details = apply_filters( 'magazine_palace_pro_filter_post_carousel_section_details', $section_details );

    if ( empty( $section_details ) ) {
        return;
    }

// Render post_carousel section now.
    magazine_palace_pro_render_post_carousel_section( $section_details );
}
endif;

if ( ! function_exists( 'magazine_palace_pro_get_post_carousel_section_details' ) ) :
/**
* post_carousel section details.
*
* @since Magazine Palace Pro 1.0.0
* @param array $input post_carousel section details.
*/
function magazine_palace_pro_get_post_carousel_section_details( $input ) {
    $options = magazine_palace_pro_get_theme_options();

// Content type.
    $post_carousel_content_type  = $options['post_carousel_content_type'];
    $post_carousel_count = ! empty( $options['post_carousel_count'] ) ? $options['post_carousel_count'] : 4;

    $content = array();
    switch ( $post_carousel_content_type ) {

        case 'post':
        $post_ids = array();

        for ( $i = 1; $i <= $post_carousel_count; $i++ ) {
            if ( ! empty( $options['post_carousel_content_post_' . $i] ) )
                $post_ids[] = $options['post_carousel_content_post_' . $i];
        }

        $args = array(
            'post_type'         => 'post',
            'post__in'          => ( array ) $post_ids,
            'posts_per_page'    => absint( $post_carousel_count ),
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
            );                    
        break;

        case 'category':
        $cat_id = ! empty( $options['post_carousel_content_category'] ) ? $options['post_carousel_content_category'] : '';
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => absint( $post_carousel_count ),
            'category__in'      => ( array ) $cat_id,
            'ignore_sticky_posts'   => true,
            );                    
        break;

        default:
        break;
    }


// Run The Loop.
    $query = new WP_Query( $args );
    if ( $query->have_posts() ) : 
        while ( $query->have_posts() ) : $query->the_post();
    $page_post['id']        = get_the_id();
    $page_post['title']     = get_the_title();
    $page_post['auth_id']   = get_the_author_meta('ID');
    $page_post['url']       = get_the_permalink();
    $page_post['excerpt']   = get_the_content();
    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

// Push to the main array.
    array_push( $content, $page_post );
    endwhile;
    endif;
    wp_reset_postdata();

    if ( ! empty( $content ) ) {
        $input = $content;
    }
    return $input;
}
endif;
// post_carousel section content details.
add_filter( 'magazine_palace_pro_filter_post_carousel_section_details', 'magazine_palace_pro_get_post_carousel_section_details' );


if ( ! function_exists( 'magazine_palace_pro_render_post_carousel_section' ) ) :
/**
* Start post_carousel section
*
* @return string post_carousel content
* @since Magazine Palace Pro 1.0.0
*
*/
function magazine_palace_pro_render_post_carousel_section( $content_details = array() ) {
    $options = magazine_palace_pro_get_theme_options();
  ?>
<div id="magazine_palace_pro_post_carousel_section" class="relative home-section post-carousel">
    <div class="wrapper">
        <?php if ( is_customize_preview()):
            magazine_palace_pro_section_tooltip( 'post-carousel-class' );
        endif; ?>
        <?php if ( ! empty( $options['post_carousel_title'] ) ) : ?>
            <div class="section-header">
                <h2 class="section-title"><?php echo esc_html( $options['post_carousel_title'] ); ?></h2>
            </div><!-- .section-header -->
        <?php endif; ?>
        <div class="magazine_palace_pro_post_carousel_section" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": <?php echo esc_attr( $options['post_carousel_autoplay_enable'] ) ?>, "draggable": true, "fade": false }'>
            <?php foreach ( $content_details as $content ) : ?>
                <article>
                    <div class="featured-wrapper">
                        <div class="featured-image">
                            <img src="<?php echo esc_url( $content['image'] ); ?>">
                        </div>
                        <?php if ( !empty( get_post_meta( $content['id'], '_magazine_palace_pro_youtube_video_code' )[0] ) ): ?>
                            <div class="video-button">
                                <a href="https://www.youtube.com/watch?v=<?php echo get_post_meta( $content['id'], '_magazine_palace_pro_youtube_video_code' )[0] ?>" class="popup-video" tabindex="-1"><i class="fa fa-play"></i></a>
                            </div>
                        <?php endif ?>

                        <div class="entry-container">
                            <span class="cat-links">
                                <?php the_category( '', '', $content['id'] ); ?>
                            </span>
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>
                            <div class="entry-meta">
                                <?php magazine_palace_pro_posted_on( $content['id'] ); ?>
                                <span class="min-read"><?php echo magazine_palace_pro_time_interval($content['excerpt']); echo esc_html__(' min to read', 'magazine-palace-pro'); ?></span>
                            </div>
                        </div>
                    </div>
                </article>
            <?php endforeach; ?>            
        </div>
    </div>
</div>
<?php }
    endif;