<?php
/**
* Post Grid section
*
* This is the template for the content of post_grid section
*
* @package Theme Palace
* @subpackage Magazine Palace Pro
* @since Magazine Palace Pro 1.0.0
*/

$options = magazine_palace_pro_get_theme_options();

if( $options['post_grid_section_enable'] !== false ):

// Content type.
$post_grid_content_type  = $options['post_grid_content_type'];
$post_grid_count = ! empty( $options['post_grid_count'] ) ? $options['post_grid_count'] : 4;

$content_details = array();
switch ( $post_grid_content_type ) {

    case 'post':
    $post_ids = array();

    for ( $i = 1; $i <= $post_grid_count; $i++ ) {
        if ( ! empty( $options['post_grid_content_post_' . $i] ) )
            $post_ids[] = $options['post_grid_content_post_' . $i];
    }

    $args = array(
        'post_type'         => 'post',
        'post__in'          => ( array ) $post_ids,
        'posts_per_page'    => absint( $post_grid_count ),
        'orderby'           => 'post__in',
        'ignore_sticky_posts'   => true,
        );                    
    break;

    case 'category':
    $cat_id = ! empty( $options['post_grid_content_category'] ) ? $options['post_grid_content_category'] : '';
    $args = array(
        'post_type'         => 'post',
        'posts_per_page'    => absint( $post_grid_count ),
        'category__in'      => ( array ) $cat_id,
        'ignore_sticky_posts'   => true,
        );                    
    break;

    default:
    break;
}


// Run The Loop.
$query = new WP_Query( $args );
if ( $query->have_posts() ) : 
    while ( $query->have_posts() ) : $query->the_post();
$page_post['id']        = get_the_id();
$page_post['title']     = get_the_title();
$page_post['auth_id']   = get_the_author_meta('ID');
$page_post['url']       = get_the_permalink();
$page_post['excerpt']   = get_the_content();
$page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

// Push to the main array.
array_push( $content_details, $page_post );
endwhile;
endif;
wp_reset_postdata();
?>

<div id="magazine_palace_pro_post_grid_section" class="relative home-section post-grid">
    <?php if ( is_customize_preview()):
        magazine_palace_pro_section_tooltip( 'post-grid-class' );
    endif; ?>
    <?php if ( ! empty( $options['post_grid_title'] ) ) : ?>
        <div class="section-header">
            <h2 class="section-title"><?php echo esc_html( $options['post_grid_title'] ); ?></h2>
        </div><!-- .section-header -->
    <?php endif; ?>
    <div class="section-content col-3">
        <?php foreach ( $content_details as $content ) : ?>
            <article>
                <div class="magazine_palace_pro_post_grid_section-wrapper">
                    <div class="featured-image">
                        <img src="<?php echo esc_url( $content['image'] ); ?>">
                    </div>
                    <?php if ( !empty( get_post_meta( $content['id'], '_magazine_palace_pro_youtube_video_code' )[0] ) ): ?>
                        <div class="video-button">
                            <a href="https://www.youtube.com/watch?v=<?php echo get_post_meta( $content['id'], '_magazine_palace_pro_youtube_video_code' )[0] ?>" class="popup-video" tabindex="-1"><i class="fa fa-play"></i></a>
                        </div>
                    <?php endif ?>

                    <div class="entry-container">
                        <span class="cat-links">
                            <?php the_category( '', '', $content['id'] ); ?>
                        </span>
                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                        </header>
                        <div class="entry-meta">
                            <?php magazine_palace_pro_posted_on( $content['id'] ); ?>
                            <span class="min-read"><?php echo magazine_palace_pro_time_interval($content['excerpt']); echo esc_html__(' min to read', 'magazine-palace-pro'); ?></span>
                        </div>
                    </div>
                </div>
            </article>
        <?php endforeach; ?>            
    </div>
</div>
<?php endif; ?>

