<?php
/**
* Related post section
*
* This is the template for the content of two_section section
*
* @package Theme Palace
* @subpackage Magazine Palace Pro
* @since Magazine Palace Pro 1.0.0
*/
if ( ! function_exists( 'magazine_palace_pro_add_two_section_section' ) ) :
/**
* Add two_section section
*
*@since Magazine Palace Pro 1.0.0
*/
function magazine_palace_pro_add_two_section_section() {
    $options = magazine_palace_pro_get_theme_options();
    // Check if two_section is enabled on frontpage
    $two_section_enable = apply_filters( 'magazine_palace_pro_section_status', true, 'two_section_section_enable' );

    if ( true !== $two_section_enable ) {
        return false;
    }
    // Get two_section section details
    $section_details = array();
    $section_details = apply_filters( 'magazine_palace_pro_filter_two_section_section_details', $section_details );

    if ( empty( $section_details ) ) {
        return;
    }

// Render two_section section now.
    magazine_palace_pro_render_two_section_section( $section_details );
}
endif;

if ( ! function_exists( 'magazine_palace_pro_get_two_section_section_details' ) ) :
/**
* two_section section details.
*
* @since Magazine Palace Pro 1.0.0
* @param array $input two_section section details.
*/
function magazine_palace_pro_get_two_section_section_details( $input ) {
    $options = magazine_palace_pro_get_theme_options();

    // Content type.
    $two_section_grid_post_content_type  = $options['two_section_grid_post_content_type'];

    $content_details = array();
    $content_details['two_section_grid_post'] = array();

    switch ( $two_section_grid_post_content_type ) {


        case 'post':
        $post_ids = array();
        for ( $i = 1; $i <= 4; $i++ ) {
            if ( ! empty( $options['two_section_grid_post_content_post_' . $i] ) ) :
                $post_ids[] = $options['two_section_grid_post_content_post_' . $i];
            endif;
        }

        $args = array(
            'post_type'         => 'post',
            'post__in'     => ( array ) $post_ids,
            'posts_per_page'    => 4,
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
            );                  
        break;

        case 'category':
        $grid_post_cat_ids = ! empty( $options['two_section_grid_post_content_category'] ) ? $options['two_section_grid_post_content_category'] : '';
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => 4,
            'category__in'      => ( array ) $grid_post_cat_ids ,
            'ignore_sticky_posts'   => true,
            );                    
        break;

        default:
        break;
    }

    // Run The Loop.
    $query = new WP_Query( $args );
    if ( $query->have_posts() ) : 
        while ( $query->have_posts() ) : $query->the_post();
            $page_post['id']        = get_the_id();
            $page_post['auth_id']   = get_the_author_meta('ID');
            $page_post['title']     = get_the_title();
            $page_post['excerpt']   = get_the_content();
            $page_post['sub_title'] = ! empty( $options['two_section_sub_title'] ) ? $options['two_section_sub_title'] : '';
            $page_post['url']       = get_the_permalink();
            $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

    // Push to the main array.
    array_push( $content_details['two_section_grid_post'], $page_post );
    endwhile;
    endif;
    wp_reset_postdata();


    $content_details['two_section_slider_post'] = array();


    $slider_post_cat_ids = ! empty( $options['two_section_slider_category'] ) ? $options['two_section_slider_category'] : '';
    $args1 = array(
        'post_type'         => 'post',
        'posts_per_page'    => -1,
        'cat'               => ( array )$slider_post_cat_ids,
        'ignore_sticky_posts'   => true,
        );                    


    // Run The Loop.
    $query = new WP_Query( $args1 );
    if ( $query->have_posts() ) : 
        while ( $query->have_posts() ) : $query->the_post();
    $two_section_page_post['id']        = get_the_id();
    $two_section_page_post['auth_id']   = get_the_author_meta('ID');
    $two_section_page_post['title']     = get_the_title();
    $two_section_page_post['excerpt']   = get_the_content();
    $two_section_page_post['url']       = get_the_permalink();
    $two_section_page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';


    // Push to the main array.
    array_push( $content_details['two_section_slider_post'], $two_section_page_post );
    endwhile;
    endif;
    wp_reset_postdata();

    if ( ! empty( $content_details ) ) {
        $input = $content_details;
    }
    return $input;
}
endif;
// two_section section content details.
add_filter( 'magazine_palace_pro_filter_two_section_section_details', 'magazine_palace_pro_get_two_section_section_details' );


if ( ! function_exists( 'magazine_palace_pro_render_two_section_section' ) ) :
/**
* Start two_section section
*
* @return string two_section content
* @since Magazine Palace Pro 1.0.0
*
*/
function magazine_palace_pro_render_two_section_section( $content_details = array() ) {
    $options = magazine_palace_pro_get_theme_options();

    if ( empty( $content_details ) ) {
        return;
    } ?>
<div id="magazine_palace_pro_two_section_section" class="home-section two-section">
    <div class="wrapper">
        <?php if ( is_customize_preview()):
            magazine_palace_pro_section_tooltip( 'two-section-class' );
        endif; ?>
        <div id="magazine_palace_pro_slider_news_section" class="relative primary-post">
            <?php if ( !empty( $options['two_section_title_one'] ) ): ?>
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['two_section_title_one'] ); ?></h2>
                </div><!-- .section-header -->
            <?php endif ?>            

            <div class="magazine_palace_pro_slider_news_section-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": <?php echo esc_attr( $options['two_section_auto_play'] ) ?>, "draggable": true, "fade": false }'>
                <?php foreach ( $content_details['two_section_slider_post'] as $content ) : ?>
                    <article>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <div class="overlay"></div>
                        </div>
                       <?php if ( !empty( get_post_meta( $content['id'], '_magazine_palace_pro_youtube_video_code' )[0] ) ): ?>
                            <div class="video-button">
                                <a href="https://www.youtube.com/watch?v=<?php echo get_post_meta( $content['id'], '_magazine_palace_pro_youtube_video_code' )[0] ?>" class="popup-video" tabindex="-1"><i class="fa fa-play"></i></a>
                            </div>
                        <?php endif ?>

                        <div class="entry-container">
                            <span class="cat-links">
                                <?php the_category( '', '', $content['id'] ); ?>
                            </span><!-- .cat-links -->
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>
                            <div class="entry-meta">
                                <?php magazine_palace_pro_posted_on( $content['id'] ); ?>
                                <span class="min-read"><?php echo magazine_palace_pro_time_interval($content['excerpt']); echo esc_html__(' min to read', 'magazine-palace-pro'); ?></span>
                            </div>
                        </div>
                    </article>

                <?php endforeach; ?>
            </div><!-- .magazine_palace_pro_slider_news_section-slider -->
        </div><!-- #magazine_palace_pro_slider_news_section-aection -->

        <div id="magazine_pro_editors_choice_section" class="relative">
            <?php if ( !empty( $options['two_section_title_two'] ) ): ?>
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['two_section_title_two'] ); ?></h2>
                </div><!-- .section-header -->
            <?php endif ?>  

            <div class="section-content col-2">
                <?php foreach ( $content_details['two_section_grid_post'] as $content ) : ?>
                    <article>
                        <div class="featured-wrapper">
                            <div class="featured-image">
                                <img src="<?php echo esc_url( $content['image'] ); ?>">
                            </div>
                            <div class="overlay"></div>
                           <?php if ( !empty( get_post_meta( $content['id'], '_magazine_palace_pro_youtube_video_code' )[0] ) ): ?>
                                <div class="video-button">
                                    <a href="https://www.youtube.com/watch?v=<?php echo get_post_meta( $content['id'], '_magazine_palace_pro_youtube_video_code' )[0] ?>" class="popup-video" tabindex="-1"><i class="fa fa-play"></i></a>
                                </div>
                            <?php endif ?>

                            <div class="entry-container">
                                <span class="cat-links">
                                    <?php the_category( '', '', $content['id'] ); ?>
                                </span>
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>
                                <div class="entry-meta">
                                    <?php magazine_palace_pro_posted_on( $content['id'] ); ?>
                                    <span class="min-read"><?php echo magazine_palace_pro_time_interval($content['excerpt']); echo esc_html__(' min to read', 'magazine-palace-pro'); ?></span>
                                </div>
                            </div>
                        </div>
                    </article>
                <?php endforeach; ?>
            </div>
        </div><!-- #magazine_pro_editors_choice_section -->
    </div>
</div>




    <?php }
    endif;
