<?php
/**
 * Posts Filter Widget
 *
 * @package Theme Palace
 * @subpackage Magazine Palace Pro
 * @since Magazine Palace Pro 1.0.0
 */

if ( ! class_exists( 'Magazine_Palace_Pro_Post_Filter' ) ) :


    class Magazine_Palace_Pro_Post_Filter extends WP_Widget {
        /**
         * Sets up the widgets name etc
         */
        public function __construct() {
            $tp_widget_posts_filter = array(
                'classname'   => 'widget_sidebar_filter',
                'description' => esc_html__( 'Retrive Posts Filter.', 'magazine-palace-pro' ),
            );
            parent::__construct( 'Magazine_Palace_Pro_Post_Filter', esc_html__( 'TP : Posts Filter', 'magazine-palace-pro' ), $tp_widget_posts_filter );
        }

        /**
         * Outputs the content of the widget
         *
         * @param array $args
         * @param array $instance
         */
        public function widget( $args, $instance ) {

            $tp_category[] = isset( $instance['category_one'] ) ? $instance['category_one'] : '';
            $tp_category[] = isset( $instance['category_two'] ) ? $instance['category_two'] : '';
            $tp_category[] = isset( $instance['category_three'] ) ? $instance['category_three'] : ''; 

            ?>

            <section id="sidebar-filter" class="widget widget_sidebar_filter">
                <div class="sidebar-tab">
                    <ul class="tabs section-header">
                        <?php 
                        $i = 1 ;
                        foreach ( $tp_category as $value ) :
                            ?>
                            <li data-tab="<?php echo esc_attr( strtolower( $value ) ) ;?>" class="<?php echo $i == 1 ? 'active': '' ?>">
                                <h2 class="section-title">
                                    <?php echo esc_html(strtoupper( get_cat_name( $value ) ) ); ?>
                                </h2>
                            </li>
                            <?php $i++; endforeach; ?>
                    </ul>
                </div><!-- .widget-header -->
                <div class="sidebar-post">
                    <?php
                    $i = 1 ; 
                    foreach ( $tp_category as $value ) {
                        ?>

                        <ul id="<?php echo esc_attr( strtolower( $value ) ) ?>" class="tab-content <?php echo $i == 1 ? 'active': '' ?>">
                                <?php 
                                $cat_id = $value;
                                $args = array(
                                    'post_type'         => 'post',
                                    'cat'               => absint( $cat_id ),
                                );
                                $query = new WP_Query( $args );
                                if ( $query->have_posts() ) : 
                                    while ( $query->have_posts() ) : $query->the_post(); 

                                        $image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                                        ?>

                                        <li>
                                            <div class="sidebar-post-wrapper">
                                                <div class="featured-image">
                                                    <img src="<?php echo esc_url($image); ?>">
                                                </div>
                                                <?php if ( !empty( get_post_meta( get_the_id(), '_magazine_palace_pro_youtube_video_code' )[0] ) ): ?>
                                                    <div class="video-button">
                                                        <a href="https://www.youtube.com/watch?v=<?php echo get_post_meta( $post->ID, '_magazine_palace_pro_youtube_video_code' )[0] ?>" class="popup-video" tabindex="-1"><i class="fa fa-play"></i></a>
                                                    </div>
                                                <?php endif ?>
                                                <div class="entry-container">
                                                    <header class="entry-header">
                                                        <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php echo esc_html( get_the_title( get_the_id() ) ); ?></a></h2>
                                                    </header>
                                                    <div class="entry-meta">
                                                        <?php magazine_palace_pro_posted_on( get_the_id() ); ?>
                                                        <span class="min-read">5 min read</span>
                                                    </div>
                                                </div>
                                            </div>
                                        </li>
                                    <?php endwhile;
                                endif;
                                wp_reset_postdata();
                                ?>

                            </ul>
                        
                        <?php
                        $i++;  
                    }
                    ?>  
                    </div><!-- .tab-content -->                      
                </section>
                <?php


            }

        /**
         * Outputs the options form on admin
         *
         * @param array $instance The widget options
         */
        public function form( $instance ) {

        ?>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'category_one' ) ); ?>"><?php esc_html_e( 'Select Category One', 'magazine-palace-pro' ); ?></label>
                <select id="<?php echo esc_attr( $this->get_field_id('category_one') ); ?>" name="<?php echo $this->get_field_name('category_one'); ?>" class="widefat" style="width:100%;">
                    <?php
                        $categories = magazine_palace_pro_get_post_cat_choices();
                        foreach($categories as $category => $value) { ?>
                        <option value="<?php echo absint( $category ); ?>" <?php selected( absint( $instance['category_one'] ), $category ); ?>><?php echo esc_html( $value ); ?></option>
                    <?php } ?>
                </select>
            </p>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'category_two' ) ); ?>"><?php esc_html_e( 'Select Category One', 'magazine-palace-pro' ); ?></label>
                <select id="<?php echo esc_attr( $this->get_field_id('category_two') ); ?>" name="<?php echo $this->get_field_name('category_two'); ?>" class="widefat" style="width:100%;">
                    <?php
                        $categories = magazine_palace_pro_get_post_cat_choices();
                        foreach($categories as $category => $value) { ?>
                        <option value="<?php echo absint( $category ); ?>" <?php selected( absint( $instance['category_two'] ), $category ); ?>><?php echo esc_html( $value ); ?></option>
                    <?php } ?>
                </select>
            </p>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'category_three' ) ); ?>"><?php esc_html_e( 'Select Category One', 'magazine-palace-pro' ); ?></label>
                <select id="<?php echo esc_attr( $this->get_field_id('category_three') ); ?>" name="<?php echo $this->get_field_name('category_three'); ?>" class="widefat" style="width:100%;">
                    <?php
                        $categories = magazine_palace_pro_get_post_cat_choices();
                        foreach($categories as $category => $value) { ?>
                        <option value="<?php echo absint( $category ); ?>" <?php selected( absint( $instance['category_three'] ), $category ); ?>><?php echo esc_html( $value ); ?></option>
                    <?php } ?>
                </select>
            </p>

        <?php }

        /**
        * Processing widget options on save
        *
        * @param array $new_instance The new options
        * @param array $old_instance The previous options
        */
        function update( $new_instance, $old_instance ) {
            $instance = array();
            $instance['category_one'] = ( !empty( $new_instance['category_one'] ) ) ? absint( $new_instance['category_one'] ) : '';
            $instance['category_two'] = ( !empty( $new_instance['category_two'] ) ) ? absint( $new_instance['category_two'] ) : '';
            $instance['category_three'] = ( !empty( $new_instance['category_three'] ) ) ? absint( $new_instance['category_three'] ) : '';
            return $instance;
        }
    }
endif;
