<?php
/**
 * Topbar design template
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Theme Palace
 * @subpackage Magazine Palace Pro
 * @since Magazine Palace Pro 1.0.0
 */

$options = magazine_palace_pro_get_theme_options();
$header_txt_logo_extra = $options['header_txt_logo_extra']; 
$header_wrapper_class = $options['header_wrapper_enable'] ? 'wrapper' : '';
?>

<header id="masthead" class="site-header header-three <?php echo $header_wrapper_class ?>" role="banner">
    <div class="wrapper">
        <div class="site-branding-container">
            <div class="site-branding-wrapper">
                <div class="site-branding">
                    <?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
                        <div class="site-logo">
                            <?php the_custom_logo(); ?>
                        </div>
                    <?php } 
                    if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
                        <div id="site-details">
                            <?php
                            if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
                                if ( magazine_palace_pro_is_latest_posts() || magazine_palace_pro_is_frontpage() ) : ?>
                                    <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                                <?php else : ?>
                                    <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
                                <?php
                                endif;
                            } 
                            if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
                                $description = get_bloginfo( 'description', 'display' );
                                if ( $description || is_customize_preview() ) : ?>
                                    <p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
                                <?php
                                endif; 
                            }?>
                        </div>
                    <?php endif; ?>
                </div><!-- .site-branding -->
            </div><!-- .site-branding-wrapper  -->

            <button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
                <?php
                echo magazine_palace_pro_get_svg( array( 'icon' => 'menu' ) );
                echo magazine_palace_pro_get_svg( array( 'icon' => 'close' ) );
                ?>     
            </button>

            <nav id="site-navigation" class="main-navigation" role="navigation" aria-label="<?php echo esc_attr( 'primary menu', 'magazine-palace-pro' ); ?>">
                <?php 
                    if($options['header_search_enable']){
                        $search_html = sprintf(
                                        '<li class="search-menu"><a href="#" title="%1$s">%2$s%3$s</a><div id="search">%4$s</div>',
                                        esc_attr__('Search','magazine-palace-pro'),
                                        magazine_palace_pro_get_svg( array( 'icon' => 'search' ) ), 
                                        magazine_palace_pro_get_svg( array( 'icon' => 'close' ) ), 
                                        get_search_form( $echo = false )
                                    );
                        
                    }else{
                        $search_html = '';
                    }

                    $home_icon = magazine_palace_pro_get_svg( array( 'icon' => 'home' ) );
                    
                    wp_nav_menu( array(
                        'theme_location' => 'primary',
                        'container' => 'div',
                        'menu_class' => 'menu nav-menu',
                        'menu_id' => 'primary-menu',
                        'echo' => true,
                        'fallback_cb' => 'magazine_palace_pro_menu_fallback_cb',
                        'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $search_html . '</ul>',
                    ) );
                ?>
            </nav><!-- .main-navigation-->
        </div>
    </div>
</header>
